from _typeshed import Unused
from typing import Final

from Xlib.display import Display
from Xlib.protocol import rq
from Xlib.xobject import drawable, resource

extname: Final = "XINERAMA"

class QueryVersion(rq.ReplyRequest): ...

def query_version(self: Display | resource.Resource) -> QueryVersion: ...

class GetState(rq.ReplyRequest): ...

def get_state(self: drawable.Window) -> GetState: ...

class GetScreenCount(rq.ReplyRequest): ...

def get_screen_count(self: drawable.Window) -> GetScreenCount: ...

class GetScreenSize(rq.ReplyRequest): ...

def get_screen_size(self: drawable.Window, screen_no: int) -> GetScreenSize: ...

class IsActive(rq.ReplyRequest): ...

def is_active(self: Display | resource.Resource) -> int: ...

class QueryScreens(rq.ReplyRequest): ...

def query_screens(self: Display | resource.Resource) -> QueryScreens: ...

class GetInfo(rq.ReplyRequest): ...

def get_info(self: Display | resource.Resource, visual: int) -> None: ...
def init(disp: Display, info: Unused) -> None: ...



from re import Pattern
from typing import ClassVar
from typing_extensions import TypeAlias

from docutils import DataError
from docutils.statemachine import StringList

_Cell: TypeAlias = tuple[int, int, int, list[str]]
_Row: TypeAlias = list[_Cell | None]
_Colspecs: TypeAlias = list[int]

__docformat__: str

class TableMarkupError(DataError):
    offset: int
    def __init__(self, *args, **kwargs) -> None: ...

class TableParser:
    head_body_separator_pat: ClassVar[Pattern[str] | None]
    double_width_pad_char: ClassVar[str]
    def parse(self, block: StringList) -> tuple[_Colspecs, list[_Row], list[_Row]]: ...
    def find_head_body_sep(self) -> None: ...

class GridTableParser(TableParser):
    head_body_separator_pat: ClassVar[Pattern[str]]
    block: StringList
    bottom: int
    right: int
    head_body_sep: int
    done: list[int]
    cells: list[_Cell]
    rowseps: dict[int, list[int]]
    colseps: dict[int, list[int]]
    def setup(self, block: StringList) -> None: ...
    def parse_table(self) -> None: ...
    def mark_done(self, top: int, left: int, bottom: int, right: int) -> None: ...
    def check_parse_complete(self) -> bool: ...
    def scan_cell(self, top: int, left: int) -> tuple[int, int, dict[int, list[int]], dict[int, list[int]]]: ...
    def scan_right(self, top: int, left: int) -> tuple[int, int, dict[int, list[int]], dict[int, list[int]]]: ...
    def scan_down(self, top: int, left: int, right: int) -> tuple[int, dict[int, list[int]], dict[int, list[int]]]: ...
    def scan_left(self, top: int, left: int, bottom: int, right: int) -> tuple[dict[int, list[int]], dict[int, list[int]]]: ...
    def scan_up(self, top: int, left: int, bottom: int, right: int) -> dict[int, list[int]]: ...
    def structure_from_cells(self) -> tuple[_Colspecs, list[_Row], list[_Row]]: ...

class SimpleTableParser(TableParser):
    head_body_separator_pat: ClassVar[Pattern[str]]
    span_pat: ClassVar[Pattern[str]]
    block: StringList
    head_body_sep: int
    columns: list[tuple[int, int]]
    border_end: int
    table: tuple[list[int], list[_Row], list[_Row]]
    done: list[int]
    rowseps: dict[int, tuple[int]]
    colseps: dict[int, tuple[int]]
    def setup(self, block: StringList) -> None: ...
    def parse_table(self) -> None: ...
    def parse_columns(self, line: str, offset: int) -> list[tuple[int, int]]: ...
    def init_row(self, colspec: list[tuple[int, int]], offset: int) -> list[_Cell]: ...
    def parse_row(self, lines: list[str], start: int, spanline: tuple[str, int] | None = ...) -> None: ...
    def check_columns(self, lines: list[str], first_line: int, columns: list[tuple[int, int]]) -> None: ...
    def structure_from_cells(self) -> tuple[_Colspecs, list[_Row], list[_Row]]: ...

def update_dict_of_lists(master: dict[int, list[int]], newdata: dict[int, list[int]]) -> None: ...



from _typeshed import ConvertibleToFloat, ConvertibleToInt, Incomplete
from datetime import datetime
from typing import ClassVar, Literal, overload

from openpyxl.descriptors.base import Bool, DateTime, Float, Integer, String, Typed, _ConvertibleToBool
from openpyxl.descriptors.serialisable import Serialisable

class Index(Serialisable):
    tagname: ClassVar[str]
    v: Integer[Literal[True]]
    def __init__(self, v: ConvertibleToInt | None = 0) -> None: ...

class Tuple(Serialisable):
    fld: Integer[Literal[False]]
    hier: Integer[Literal[False]]
    item: Integer[Literal[False]]
    def __init__(self, fld: ConvertibleToInt, hier: ConvertibleToInt, item: ConvertibleToInt) -> None: ...

class TupleList(Serialisable):
    c: Integer[Literal[True]]
    tpl: Typed[Tuple, Literal[False]]
    __elements__: ClassVar[tuple[str, ...]]
    @overload
    def __init__(self, c: ConvertibleToInt | None = None, *, tpl: Tuple) -> None: ...
    @overload
    def __init__(self, c: ConvertibleToInt | None, tpl: Tuple) -> None: ...

class Missing(Serialisable):
    tagname: ClassVar[str]
    tpls: Incomplete
    x: Incomplete
    u: Bool[Literal[True]]
    f: Bool[Literal[True]]
    c: String[Literal[True]]
    cp: Integer[Literal[True]]
    _in: Integer[Literal[True]]  # Not private. Avoids name clash
    bc: Incomplete
    fc: Incomplete
    i: Bool[Literal[True]]
    un: Bool[Literal[True]]
    st: Bool[Literal[True]]
    b: Bool[Literal[True]]
    __elements__: ClassVar[tuple[str, ...]]
    def __init__(
        self,
        tpls=(),
        x=(),
        u: _ConvertibleToBool | None = None,
        f: _ConvertibleToBool | None = None,
        c: str | None = None,
        cp: ConvertibleToInt | None = None,
        _in: ConvertibleToInt | None = None,
        bc: Incomplete | None = None,
        fc: Incomplete | None = None,
        i: _ConvertibleToBool | None = None,
        un: _ConvertibleToBool | None = None,
        st: _ConvertibleToBool | None = None,
        b: _ConvertibleToBool | None = None,
    ) -> None: ...

class Number(Serialisable):
    tagname: ClassVar[str]
    tpls: Incomplete
    x: Incomplete
    v: Float[Literal[False]]
    u: Bool[Literal[True]]
    f: Bool[Literal[True]]
    c: String[Literal[True]]
    cp: Integer[Literal[True]]
    _in: Integer[Literal[True]]  # Not private. Avoids name clash
    bc: Incomplete
    fc: Incomplete
    i: Bool[Literal[True]]
    un: Bool[Literal[True]]
    st: Bool[Literal[True]]
    b: Bool[Literal[True]]
    __elements__: ClassVar[tuple[str, ...]]
    @overload
    def __init__(
        self,
        tpls=(),
        x=(),
        *,
        v: ConvertibleToFloat,
        u: _ConvertibleToBool | None = None,
        f: _ConvertibleToBool | None = None,
        c: str | None = None,
        cp: ConvertibleToInt | None = None,
        _in: ConvertibleToInt | None = None,
        bc: Incomplete | None = None,
        fc: Incomplete | None = None,
        i: _ConvertibleToBool | None = None,
        un: _ConvertibleToBool | None = None,
        st: _ConvertibleToBool | None = None,
        b: _ConvertibleToBool | None = None,
    ) -> None: ...
    @overload
    def __init__(
        self,
        tpls,
        x,
        v: ConvertibleToFloat,
        u: _ConvertibleToBool | None = None,
        f: _ConvertibleToBool | None = None,
        c: str | None = None,
        cp: ConvertibleToInt | None = None,
        _in: ConvertibleToInt | None = None,
        bc: Incomplete | None = None,
        fc: Incomplete | None = None,
        i: _ConvertibleToBool | None = None,
        un: _ConvertibleToBool | None = None,
        st: _ConvertibleToBool | None = None,
        b: _ConvertibleToBool | None = None,
    ) -> None: ...

class Error(Serialisable):
    tagname: ClassVar[str]
    tpls: Typed[TupleList, Literal[True]]
    x: Incomplete
    v: String[Literal[False]]
    u: Bool[Literal[True]]
    f: Bool[Literal[True]]
    c: String[Literal[True]]
    cp: Integer[Literal[True]]
    _in: Integer[Literal[True]]  # Not private. Avoids name clash
    bc: Incomplete
    fc: Incomplete
    i: Bool[Literal[True]]
    un: Bool[Literal[True]]
    st: Bool[Literal[True]]
    b: Bool[Literal[True]]
    __elements__: ClassVar[tuple[str, ...]]
    @overload
    def __init__(
        self,
        tpls: TupleList | None = None,
        x=(),
        *,
        v: str,
        u: _ConvertibleToBool | None = None,
        f: _ConvertibleToBool | None = None,
        c: str | None = None,
        cp: ConvertibleToInt | None = None,
        _in: ConvertibleToInt | None = None,
        bc: Incomplete | None = None,
        fc: Incomplete | None = None,
        i: _ConvertibleToBool | None = None,
        un: _ConvertibleToBool | None = None,
        st: _ConvertibleToBool | None = None,
        b: _ConvertibleToBool | None = None,
    ) -> None: ...
    @overload
    def __init__(
        self,
        tpls: TupleList | None,
        x,
        v: str,
        u: _ConvertibleToBool | None = None,
        f: _ConvertibleToBool | None = None,
        c: str | None = None,
        cp: ConvertibleToInt | None = None,
        _in: ConvertibleToInt | None = None,
        bc: Incomplete | None = None,
        fc: Incomplete | None = None,
        i: _ConvertibleToBool | None = None,
        un: _ConvertibleToBool | None = None,
        st: _ConvertibleToBool | None = None,
        b: _ConvertibleToBool | None = None,
    ) -> None: ...

class Boolean(Serialisable):
    tagname: ClassVar[str]
    x: Incomplete
    v: Bool[Literal[False]]
    u: Bool[Literal[True]]
    f: Bool[Literal[True]]
    c: String[Literal[True]]
    cp: Integer[Literal[True]]
    __elements__: ClassVar[tuple[str, ...]]
    def __init__(
        self,
        x=(),
        v: _ConvertibleToBool = None,
        u: _ConvertibleToBool | None = None,
        f: _ConvertibleToBool | None = None,
        c: str | None = None,
        cp: ConvertibleToInt | None = None,
    ) -> None: ...

class Text(Serialisable):
    tagname: ClassVar[str]
    tpls: Incomplete
    x: Incomplete
    v: String[Literal[False]]
    u: Bool[Literal[True]]
    f: Bool[Literal[True]]
    c: String[Literal[True]]
    cp: Integer[Literal[True]]
    _in: Integer[Literal[True]]  # Not private. Avoids name clash
    bc: Incomplete
    fc: Incomplete
    i: Bool[Literal[True]]
    un: Bool[Literal[True]]
    st: Bool[Literal[True]]
    b: Bool[Literal[True]]
    __elements__: ClassVar[tuple[str, ...]]
    def __init__(
        self,
        tpls=(),
        x=(),
        v: Incomplete | None = None,
        u: _ConvertibleToBool | None = None,
        f: _ConvertibleToBool | None = None,
        c: Incomplete | None = None,
        cp: ConvertibleToInt | None = None,
        _in: ConvertibleToInt | None = None,
        bc: Incomplete | None = None,
        fc: Incomplete | None = None,
        i: _ConvertibleToBool | None = None,
        un: _ConvertibleToBool | None = None,
        st: _ConvertibleToBool | None = None,
        b: _ConvertibleToBool | None = None,
    ) -> None: ...

class DateTimeField(Serialisable):
    tagname: ClassVar[str]
    x: Incomplete
    v: DateTime[Literal[False]]
    u: Bool[Literal[True]]
    f: Bool[Literal[True]]
    c: String[Literal[True]]
    cp: Integer[Literal[True]]
    __elements__: ClassVar[tuple[str, ...]]
    def __init__(
        self,
        x=(),
        v: datetime | str | None = None,
        u: _ConvertibleToBool | None = None,
        f: _ConvertibleToBool | None = None,
        c: str | None = None,
        cp: ConvertibleToInt | None = None,
    ) -> None: ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def laplacian_matrix(G, nodelist: Incomplete | None = None, weight: str = "weight"): ...
@_dispatch
def normalized_laplacian_matrix(G, nodelist: Incomplete | None = None, weight: str = "weight"): ...
@_dispatch
def total_spanning_tree_weight(G, weight: Incomplete | None = None): ...
@_dispatch
def directed_laplacian_matrix(
    G, nodelist: Incomplete | None = None, weight: str = "weight", walk_type: Incomplete | None = None, alpha: float = 0.95
): ...
@_dispatch
def directed_combinatorial_laplacian_matrix(
    G, nodelist: Incomplete | None = None, weight: str = "weight", walk_type: Incomplete | None = None, alpha: float = 0.95
): ...



from _typeshed import Incomplete
from typing import Any

def constant_to_class_kind(value): ...
def constant_to_attribute_usage(value): ...
def attribute_usage_to_constant(value): ...
def quoted_string_to_list(quoted_string): ...
def oids_string_to_list(oid_string): ...
def extension_to_tuple(extension_string): ...
def list_to_string(list_object): ...

class BaseServerInfo:
    raw: Any
    def __init__(self, raw_attributes) -> None: ...
    @classmethod
    def from_json(cls, json_definition, schema: Incomplete | None = None, custom_formatter: Incomplete | None = None): ...
    @classmethod
    def from_file(cls, target, schema: Incomplete | None = None, custom_formatter: Incomplete | None = None): ...
    def to_file(self, target, indent: int = 4, sort: bool = True) -> None: ...
    def to_json(self, indent: int = 4, sort: bool = True): ...

class DsaInfo(BaseServerInfo):
    alt_servers: Any
    naming_contexts: Any
    supported_controls: Any
    supported_extensions: Any
    supported_features: Any
    supported_ldap_versions: Any
    supported_sasl_mechanisms: Any
    vendor_name: Any
    vendor_version: Any
    schema_entry: Any
    other: Any
    def __init__(self, attributes, raw_attributes) -> None: ...

class SchemaInfo(BaseServerInfo):
    schema_entry: Any
    create_time_stamp: Any
    modify_time_stamp: Any
    attribute_types: Any
    object_classes: Any
    matching_rules: Any
    matching_rule_uses: Any
    dit_content_rules: Any
    dit_structure_rules: Any
    name_forms: Any
    ldap_syntaxes: Any
    other: Any
    def __init__(self, schema_entry, attributes, raw_attributes) -> None: ...
    def is_valid(self): ...

class BaseObjectInfo:
    oid: Any
    name: Any
    description: Any
    obsolete: Any
    extensions: Any
    experimental: Any
    raw_definition: Any
    def __init__(
        self,
        oid: Incomplete | None = None,
        name: Incomplete | None = None,
        description: Incomplete | None = None,
        obsolete: bool = False,
        extensions: Incomplete | None = None,
        experimental: Incomplete | None = None,
        definition: Incomplete | None = None,
    ) -> None: ...
    @property
    def oid_info(self): ...
    @classmethod
    def from_definition(cls, definitions): ...

class MatchingRuleInfo(BaseObjectInfo):
    syntax: Any
    def __init__(
        self,
        oid: Incomplete | None = None,
        name: Incomplete | None = None,
        description: Incomplete | None = None,
        obsolete: bool = False,
        syntax: Incomplete | None = None,
        extensions: Incomplete | None = None,
        experimental: Incomplete | None = None,
        definition: Incomplete | None = None,
    ) -> None: ...

class MatchingRuleUseInfo(BaseObjectInfo):
    apply_to: Any
    def __init__(
        self,
        oid: Incomplete | None = None,
        name: Incomplete | None = None,
        description: Incomplete | None = None,
        obsolete: bool = False,
        apply_to: Incomplete | None = None,
        extensions: Incomplete | None = None,
        experimental: Incomplete | None = None,
        definition: Incomplete | None = None,
    ) -> None: ...

class ObjectClassInfo(BaseObjectInfo):
    superior: Any
    kind: Any
    must_contain: Any
    may_contain: Any
    def __init__(
        self,
        oid: Incomplete | None = None,
        name: Incomplete | None = None,
        description: Incomplete | None = None,
        obsolete: bool = False,
        superior: Incomplete | None = None,
        kind: Incomplete | None = None,
        must_contain: Incomplete | None = None,
        may_contain: Incomplete | None = None,
        extensions: Incomplete | None = None,
        experimental: Incomplete | None = None,
        definition: Incomplete | None = None,
    ) -> None: ...

class AttributeTypeInfo(BaseObjectInfo):
    superior: Any
    equality: Any
    ordering: Any
    substring: Any
    syntax: Any
    min_length: Any
    single_value: Any
    collective: Any
    no_user_modification: Any
    usage: Any
    mandatory_in: Any
    optional_in: Any
    def __init__(
        self,
        oid: Incomplete | None = None,
        name: Incomplete | None = None,
        description: Incomplete | None = None,
        obsolete: bool = False,
        superior: Incomplete | None = None,
        equality: Incomplete | None = None,
        ordering: Incomplete | None = None,
        substring: Incomplete | None = None,
        syntax: Incomplete | None = None,
        min_length: Incomplete | None = None,
        single_value: bool = False,
        collective: bool = False,
        no_user_modification: bool = False,
        usage: Incomplete | None = None,
        extensions: Incomplete | None = None,
        experimental: Incomplete | None = None,
        definition: Incomplete | None = None,
    ) -> None: ...

class LdapSyntaxInfo(BaseObjectInfo):
    def __init__(
        self,
        oid: Incomplete | None = None,
        description: Incomplete | None = None,
        extensions: Incomplete | None = None,
        experimental: Incomplete | None = None,
        definition: Incomplete | None = None,
    ) -> None: ...

class DitContentRuleInfo(BaseObjectInfo):
    auxiliary_classes: Any
    must_contain: Any
    may_contain: Any
    not_contains: Any
    def __init__(
        self,
        oid: Incomplete | None = None,
        name: Incomplete | None = None,
        description: Incomplete | None = None,
        obsolete: bool = False,
        auxiliary_classes: Incomplete | None = None,
        must_contain: Incomplete | None = None,
        may_contain: Incomplete | None = None,
        not_contains: Incomplete | None = None,
        extensions: Incomplete | None = None,
        experimental: Incomplete | None = None,
        definition: Incomplete | None = None,
    ) -> None: ...

class DitStructureRuleInfo(BaseObjectInfo):
    superior: Any
    name_form: Any
    def __init__(
        self,
        oid: Incomplete | None = None,
        name: Incomplete | None = None,
        description: Incomplete | None = None,
        obsolete: bool = False,
        name_form: Incomplete | None = None,
        superior: Incomplete | None = None,
        extensions: Incomplete | None = None,
        experimental: Incomplete | None = None,
        definition: Incomplete | None = None,
    ) -> None: ...

class NameFormInfo(BaseObjectInfo):
    object_class: Any
    must_contain: Any
    may_contain: Any
    def __init__(
        self,
        oid: Incomplete | None = None,
        name: Incomplete | None = None,
        description: Incomplete | None = None,
        obsolete: bool = False,
        object_class: Incomplete | None = None,
        must_contain: Incomplete | None = None,
        may_contain: Incomplete | None = None,
        extensions: Incomplete | None = None,
        experimental: Incomplete | None = None,
        definition: Incomplete | None = None,
    ) -> None: ...



from _typeshed import Incomplete
from typing import Any

from stripe import error as error, http_client as http_client, oauth_error as oauth_error, version as version
from stripe.multipart_data_generator import MultipartDataGenerator as MultipartDataGenerator
from stripe.stripe_response import StripeResponse as StripeResponse, StripeStreamResponse as StripeStreamResponse

class APIRequestor:
    api_base: Any
    api_key: Any
    api_version: Any
    stripe_account: Any
    def __init__(
        self,
        key: Incomplete | None = None,
        client: Incomplete | None = None,
        api_base: Incomplete | None = None,
        api_version: Incomplete | None = None,
        account: Incomplete | None = None,
    ) -> None: ...
    @classmethod
    def format_app_info(cls, info): ...
    def request(self, method, url, params: Incomplete | None = None, headers: Incomplete | None = None): ...
    def request_stream(self, method, url, params: Incomplete | None = None, headers: Incomplete | None = None): ...
    def handle_error_response(self, rbody, rcode, resp, rheaders) -> None: ...
    def specific_api_error(self, rbody, rcode, resp, rheaders, error_data): ...
    def specific_oauth_error(self, rbody, rcode, resp, rheaders, error_code): ...
    def request_headers(self, api_key, method): ...
    def request_raw(
        self,
        method,
        url,
        params: Incomplete | None = None,
        supplied_headers: Incomplete | None = None,
        is_streaming: bool = False,
    ): ...
    def interpret_response(self, rbody, rcode, rheaders): ...
    def interpret_streaming_response(self, stream, rcode, rheaders): ...



from _typeshed import Incomplete
from collections.abc import Generator

__all__ = ["GraphMatcher", "DiGraphMatcher"]

class GraphMatcher:
    G1: Incomplete
    G2: Incomplete
    G1_nodes: Incomplete
    G2_nodes: Incomplete
    G2_node_order: Incomplete
    old_recursion_limit: Incomplete
    test: str
    def __init__(self, G1, G2) -> None: ...
    def reset_recursion_limit(self) -> None: ...
    def candidate_pairs_iter(self) -> Generator[Incomplete, None, None]: ...
    core_1: Incomplete
    core_2: Incomplete
    inout_1: Incomplete
    inout_2: Incomplete
    state: Incomplete
    mapping: Incomplete
    def initialize(self) -> None: ...
    def is_isomorphic(self): ...
    def isomorphisms_iter(self) -> Generator[Incomplete, Incomplete, None]: ...
    def match(self) -> Generator[Incomplete, Incomplete, None]: ...
    def semantic_feasibility(self, G1_node, G2_node): ...
    def subgraph_is_isomorphic(self): ...
    def subgraph_is_monomorphic(self): ...
    def subgraph_isomorphisms_iter(self) -> Generator[Incomplete, Incomplete, None]: ...
    def subgraph_monomorphisms_iter(self) -> Generator[Incomplete, Incomplete, None]: ...
    def syntactic_feasibility(self, G1_node, G2_node): ...

class DiGraphMatcher(GraphMatcher):
    def __init__(self, G1, G2) -> None: ...
    def candidate_pairs_iter(self) -> Generator[Incomplete, None, None]: ...
    core_1: Incomplete
    core_2: Incomplete
    in_1: Incomplete
    in_2: Incomplete
    out_1: Incomplete
    out_2: Incomplete
    state: Incomplete
    mapping: Incomplete
    def initialize(self) -> None: ...
    def syntactic_feasibility(self, G1_node, G2_node): ...

class GMState:
    GM: Incomplete
    G1_node: Incomplete
    G2_node: Incomplete
    depth: Incomplete
    def __init__(self, GM, G1_node: Incomplete | None = None, G2_node: Incomplete | None = None) -> None: ...
    def restore(self) -> None: ...

class DiGMState:
    GM: Incomplete
    G1_node: Incomplete
    G2_node: Incomplete
    depth: Incomplete
    def __init__(self, GM, G1_node: Incomplete | None = None, G2_node: Incomplete | None = None) -> None: ...
    def restore(self) -> None: ...



from enum import IntEnum, IntFlag
from typing import ClassVar, Final, Literal

from .ImageFile import ImageFile, PyDecoder

DDS_MAGIC: Final = 0x20534444

class DDSD(IntFlag):
    CAPS = 0x1
    HEIGHT = 0x2
    WIDTH = 0x4
    PITCH = 0x8
    PIXELFORMAT = 0x1000
    MIPMAPCOUNT = 0x20000
    LINEARSIZE = 0x80000
    DEPTH = 0x800000

class DDSCAPS(IntFlag):
    COMPLEX = 0x8
    TEXTURE = 0x1000
    MIPMAP = 0x400000

class DDSCAPS2(IntFlag):
    CUBEMAP = 0x200
    CUBEMAP_POSITIVEX = 0x400
    CUBEMAP_NEGATIVEX = 0x800
    CUBEMAP_POSITIVEY = 0x1000
    CUBEMAP_NEGATIVEY = 0x2000
    CUBEMAP_POSITIVEZ = 0x4000
    CUBEMAP_NEGATIVEZ = 0x8000
    VOLUME = 0x200000

class DDPF(IntFlag):
    ALPHAPIXELS = 0x1
    ALPHA = 0x2
    FOURCC = 0x4
    PALETTEINDEXED8 = 0x20
    RGB = 0x40
    LUMINANCE = 0x20000

class DXGI_FORMAT(IntEnum):
    UNKNOWN = 0
    R32G32B32A32_TYPELESS = 1
    R32G32B32A32_FLOAT = 2
    R32G32B32A32_UINT = 3
    R32G32B32A32_SINT = 4
    R32G32B32_TYPELESS = 5
    R32G32B32_FLOAT = 6
    R32G32B32_UINT = 7
    R32G32B32_SINT = 8
    R16G16B16A16_TYPELESS = 9
    R16G16B16A16_FLOAT = 10
    R16G16B16A16_UNORM = 11
    R16G16B16A16_UINT = 12
    R16G16B16A16_SNORM = 13
    R16G16B16A16_SINT = 14
    R32G32_TYPELESS = 15
    R32G32_FLOAT = 16
    R32G32_UINT = 17
    R32G32_SINT = 18
    R32G8X24_TYPELESS = 19
    D32_FLOAT_S8X24_UINT = 20
    R32_FLOAT_X8X24_TYPELESS = 21
    X32_TYPELESS_G8X24_UINT = 22
    R10G10B10A2_TYPELESS = 23
    R10G10B10A2_UNORM = 24
    R10G10B10A2_UINT = 25
    R11G11B10_FLOAT = 26
    R8G8B8A8_TYPELESS = 27
    R8G8B8A8_UNORM = 28
    R8G8B8A8_UNORM_SRGB = 29
    R8G8B8A8_UINT = 30
    R8G8B8A8_SNORM = 31
    R8G8B8A8_SINT = 32
    R16G16_TYPELESS = 33
    R16G16_FLOAT = 34
    R16G16_UNORM = 35
    R16G16_UINT = 36
    R16G16_SNORM = 37
    R16G16_SINT = 38
    R32_TYPELESS = 39
    D32_FLOAT = 40
    R32_FLOAT = 41
    R32_UINT = 42
    R32_SINT = 43
    R24G8_TYPELESS = 44
    D24_UNORM_S8_UINT = 45
    R24_UNORM_X8_TYPELESS = 46
    X24_TYPELESS_G8_UINT = 47
    R8G8_TYPELESS = 48
    R8G8_UNORM = 49
    R8G8_UINT = 50
    R8G8_SNORM = 51
    R8G8_SINT = 52
    R16_TYPELESS = 53
    R16_FLOAT = 54
    D16_UNORM = 55
    R16_UNORM = 56
    R16_UINT = 57
    R16_SNORM = 58
    R16_SINT = 59
    R8_TYPELESS = 60
    R8_UNORM = 61
    R8_UINT = 62
    R8_SNORM = 63
    R8_SINT = 64
    A8_UNORM = 65
    R1_UNORM = 66
    R9G9B9E5_SHAREDEXP = 67
    R8G8_B8G8_UNORM = 68
    G8R8_G8B8_UNORM = 69
    BC1_TYPELESS = 70
    BC1_UNORM = 71
    BC1_UNORM_SRGB = 72
    BC2_TYPELESS = 73
    BC2_UNORM = 74
    BC2_UNORM_SRGB = 75
    BC3_TYPELESS = 76
    BC3_UNORM = 77
    BC3_UNORM_SRGB = 78
    BC4_TYPELESS = 79
    BC4_UNORM = 80
    BC4_SNORM = 81
    BC5_TYPELESS = 82
    BC5_UNORM = 83
    BC5_SNORM = 84
    B5G6R5_UNORM = 85
    B5G5R5A1_UNORM = 86
    B8G8R8A8_UNORM = 87
    B8G8R8X8_UNORM = 88
    R10G10B10_XR_BIAS_A2_UNORM = 89
    B8G8R8A8_TYPELESS = 90
    B8G8R8A8_UNORM_SRGB = 91
    B8G8R8X8_TYPELESS = 92
    B8G8R8X8_UNORM_SRGB = 93
    BC6H_TYPELESS = 94
    BC6H_UF16 = 95
    BC6H_SF16 = 96
    BC7_TYPELESS = 97
    BC7_UNORM = 98
    BC7_UNORM_SRGB = 99
    AYUV = 100
    Y410 = 101
    Y416 = 102
    NV12 = 103
    P010 = 104
    P016 = 105
    OPAQUE_420 = 106
    YUY2 = 107
    Y210 = 108
    Y216 = 109
    NV11 = 110
    AI44 = 111
    IA44 = 112
    P8 = 113
    A8P8 = 114
    B4G4R4A4_UNORM = 115
    P208 = 130
    V208 = 131
    V408 = 132
    SAMPLER_FEEDBACK_MIN_MIP_OPAQUE = 189
    SAMPLER_FEEDBACK_MIP_REGION_USED_OPAQUE = 190

class D3DFMT(IntEnum):
    UNKNOWN = 0
    R8G8B8 = 20
    A8R8G8B8 = 21
    X8R8G8B8 = 22
    R5G6B5 = 23
    X1R5G5B5 = 24
    A1R5G5B5 = 25
    A4R4G4B4 = 26
    R3G3B2 = 27
    A8 = 28
    A8R3G3B2 = 29
    X4R4G4B4 = 30
    A2B10G10R10 = 31
    A8B8G8R8 = 32
    X8B8G8R8 = 33
    G16R16 = 34
    A2R10G10B10 = 35
    A16B16G16R16 = 36
    A8P8 = 40
    P8 = 41
    L8 = 50
    A8L8 = 51
    A4L4 = 52
    V8U8 = 60
    L6V5U5 = 61
    X8L8V8U8 = 62
    Q8W8V8U8 = 63
    V16U16 = 64
    A2W10V10U10 = 67
    D16_LOCKABLE = 70
    D32 = 71
    D15S1 = 73
    D24S8 = 75
    D24X8 = 77
    D24X4S4 = 79
    D16 = 80
    D32F_LOCKABLE = 82
    D24FS8 = 83
    D32_LOCKABLE = 84
    S8_LOCKABLE = 85
    L16 = 81
    VERTEXDATA = 100
    INDEX16 = 101
    INDEX32 = 102
    Q16W16V16U16 = 110
    R16F = 111
    G16R16F = 112
    A16B16G16R16F = 113
    R32F = 114
    G32R32F = 115
    A32B32G32R32F = 116
    CxV8U8 = 117
    A1 = 118
    A2B10G10R10_XR_BIAS = 119
    BINARYBUFFER = 199

    UYVY: int
    R8G8_B8G8: int
    YUY2: int
    G8R8_G8B8: int
    DXT1: int
    DXT2: int
    DXT3: int
    DXT4: int
    DXT5: int
    DX10: int
    BC4S: int
    BC4U: int
    BC5S: int
    BC5U: int
    ATI1: int
    ATI2: int
    MULTI2_ARGB8: int

DDSD_CAPS: Final = 0x1
DDSD_HEIGHT: Final = 0x2
DDSD_WIDTH: Final = 0x4
DDSD_PITCH: Final = 0x8
DDSD_PIXELFORMAT: Final = 0x1000
DDSD_MIPMAPCOUNT: Final = 0x20000
DDSD_LINEARSIZE: Final = 0x80000
DDSD_DEPTH: Final = 0x800000

DDSCAPS_COMPLEX: Final = 0x8
DDSCAPS_TEXTURE: Final = 0x1000
DDSCAPS_MIPMAP: Final = 0x400000

DDSCAPS2_CUBEMAP: Final = 0x200
DDSCAPS2_CUBEMAP_POSITIVEX: Final = 0x400
DDSCAPS2_CUBEMAP_NEGATIVEX: Final = 0x800
DDSCAPS2_CUBEMAP_POSITIVEY: Final = 0x1000
DDSCAPS2_CUBEMAP_NEGATIVEY: Final = 0x2000
DDSCAPS2_CUBEMAP_POSITIVEZ: Final = 0x4000
DDSCAPS2_CUBEMAP_NEGATIVEZ: Final = 0x8000
DDSCAPS2_VOLUME: Final = 0x200000

DDPF_ALPHAPIXELS: Final = 0x1
DDPF_ALPHA: Final = 0x2
DDPF_FOURCC: Final = 0x4
DDPF_PALETTEINDEXED8: Final = 0x20
DDPF_RGB: Final = 0x40
DDPF_LUMINANCE: Final = 0x20000

DDS_FOURCC: Final = 0x4
DDS_RGB: Final = 0x40
DDS_RGBA: Final = 0x41
DDS_LUMINANCE: Final = 0x20000
DDS_LUMINANCEA: Final = 0x20001
DDS_ALPHA: Final = 0x2
DDS_PAL8: Final = 0x20

DDS_HEADER_FLAGS_TEXTURE: int
DDS_HEADER_FLAGS_MIPMAP: int
DDS_HEADER_FLAGS_VOLUME: int
DDS_HEADER_FLAGS_PITCH: int
DDS_HEADER_FLAGS_LINEARSIZE: int
DDS_HEIGHT: int
DDS_WIDTH: int
DDS_SURFACE_FLAGS_TEXTURE: int
DDS_SURFACE_FLAGS_MIPMAP: int
DDS_SURFACE_FLAGS_CUBEMAP: int
DDS_CUBEMAP_POSITIVEX: int
DDS_CUBEMAP_NEGATIVEX: int
DDS_CUBEMAP_POSITIVEY: int
DDS_CUBEMAP_NEGATIVEY: int
DDS_CUBEMAP_POSITIVEZ: int
DDS_CUBEMAP_NEGATIVEZ: int

DXT1_FOURCC: Final = 0x31545844
DXT3_FOURCC: Final = 0x33545844
DXT5_FOURCC: Final = 0x35545844

DXGI_FORMAT_R8G8B8A8_TYPELESS: Final = 27
DXGI_FORMAT_R8G8B8A8_UNORM: Final = 28
DXGI_FORMAT_R8G8B8A8_UNORM_SRGB: Final = 29
DXGI_FORMAT_BC5_TYPELESS: Final = 82
DXGI_FORMAT_BC5_UNORM: Final = 83
DXGI_FORMAT_BC5_SNORM: Final = 84
DXGI_FORMAT_BC6H_UF16: Final = 95
DXGI_FORMAT_BC6H_SF16: Final = 96
DXGI_FORMAT_BC7_TYPELESS: Final = 97
DXGI_FORMAT_BC7_UNORM: Final = 98
DXGI_FORMAT_BC7_UNORM_SRGB: Final = 99

class DdsImageFile(ImageFile):
    format: ClassVar[Literal["DDS"]]
    format_description: ClassVar[str]
    def load_seek(self, pos: int) -> None: ...

class DdsRgbDecoder(PyDecoder): ...



from _typeshed import Incomplete
from typing import Any

class AttrDef:
    name: Any
    key: Any
    validate: Any
    pre_query: Any
    post_query: Any
    default: Any
    dereference_dn: Any
    description: Any
    mandatory: Any
    single_value: Any
    oid_info: Any
    other_names: Any
    def __init__(
        self,
        name,
        key: Incomplete | None = None,
        validate: Incomplete | None = None,
        pre_query: Incomplete | None = None,
        post_query: Incomplete | None = None,
        default=...,
        dereference_dn: Incomplete | None = None,
        description: Incomplete | None = None,
        mandatory: bool = False,
        single_value: Incomplete | None = None,
        alias: Incomplete | None = None,
    ) -> None: ...
    def __eq__(self, other): ...
    def __lt__(self, other): ...
    def __hash__(self) -> int: ...
    def __setattr__(self, key: str, value) -> None: ...



import socket
from typing_extensions import TypeAlias

_Port: TypeAlias = int

__all__ = ("bind", "is_port_free", "pick_unused_port", "return_port", "add_reserved_port", "get_port_from_port_server")

class NoFreePortFoundError(Exception): ...

def add_reserved_port(port: _Port) -> None: ...
def return_port(port: _Port) -> None: ...
def bind(port: _Port, socket_type: socket.SocketKind, socket_proto: int) -> _Port | None: ...
def is_port_free(port: _Port) -> bool: ...
def pick_unused_port(pid: int | None = None, portserver_address: str | None = None) -> _Port: ...
def get_port_from_port_server(portserver_address: str, pid: int | None = None) -> _Port | None: ...

# legacy aliases
Bind = bind
GetPortFromPortServer = get_port_from_port_server
IsPortFree = is_port_free
PickUnusedPort = pick_unused_port



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def attr_matrix(
    G,
    edge_attr: Incomplete | None = None,
    node_attr: Incomplete | None = None,
    normalized: bool = False,
    rc_order: Incomplete | None = None,
    dtype: Incomplete | None = None,
    order: Incomplete | None = None,
): ...
@_dispatch
def attr_sparse_matrix(
    G,
    edge_attr: Incomplete | None = None,
    node_attr: Incomplete | None = None,
    normalized: bool = False,
    rc_order: Incomplete | None = None,
    dtype: Incomplete | None = None,
): ...



from typing import ClassVar

from .core import UnitedStates

class Oklahoma(UnitedStates):
    include_thanksgiving_friday: ClassVar[bool]
    include_boxing_day: ClassVar[bool]
    include_columbus_day: ClassVar[bool]



from _typeshed import SupportsRead
from xml.dom.expatbuilder import ExpatBuilder as _ExpatBuilder, Namespaces as _Namespaces
from xml.dom.minidom import Document
from xml.dom.xmlbuilder import Options

__origin__: str

class DefusedExpatBuilder(_ExpatBuilder):
    forbid_dtd: bool
    forbid_entities: bool
    forbid_external: bool
    def __init__(
        self, options: Options | None = None, forbid_dtd: bool = False, forbid_entities: bool = True, forbid_external: bool = True
    ) -> None: ...
    def defused_start_doctype_decl(self, name, sysid, pubid, has_internal_subset) -> None: ...
    def defused_entity_decl(self, name, is_parameter_entity, value, base, sysid, pubid, notation_name) -> None: ...
    def defused_unparsed_entity_decl(self, name, base, sysid, pubid, notation_name) -> None: ...
    def defused_external_entity_ref_handler(self, context, base, sysid, pubid) -> None: ...
    def install(self, parser) -> None: ...

class DefusedExpatBuilderNS(_Namespaces, DefusedExpatBuilder):
    def install(self, parser) -> None: ...
    def reset(self) -> None: ...

def parse(
    file: str | SupportsRead[bytes | str],
    namespaces: bool = True,
    forbid_dtd: bool = False,
    forbid_entities: bool = True,
    forbid_external: bool = True,
) -> Document: ...
def parseString(
    string: str, namespaces: bool = True, forbid_dtd: bool = False, forbid_entities: bool = True, forbid_external: bool = True
) -> Document: ...



from _typeshed import Incomplete

class PatchStackRequest:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        name: Incomplete | None = None,
        description: Incomplete | None = None,
        template_ur_ls: Incomplete | None = None,
        additional_resources: Incomplete | None = None,
    ) -> None: ...
    @property
    def name(self): ...
    @name.setter
    def name(self, name) -> None: ...
    @property
    def description(self): ...
    @description.setter
    def description(self, description) -> None: ...
    @property
    def template_ur_ls(self): ...
    @template_ur_ls.setter
    def template_ur_ls(self, template_ur_ls) -> None: ...
    @property
    def additional_resources(self): ...
    @additional_resources.setter
    def additional_resources(self, additional_resources) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

from antlr4.atn.ATNConfigSet import ATNConfigSet as ATNConfigSet
from antlr4.atn.SemanticContext import SemanticContext as SemanticContext

class PredPrediction:
    alt: Incomplete
    pred: Incomplete
    def __init__(self, pred: SemanticContext, alt: int) -> None: ...

class DFAState:
    stateNumber: Incomplete
    configs: Incomplete
    edges: Incomplete
    isAcceptState: bool
    prediction: int
    lexerActionExecutor: Incomplete
    requiresFullContext: bool
    predicates: Incomplete
    def __init__(self, stateNumber: int = -1, configs: ATNConfigSet = ...) -> None: ...
    def getAltSet(self): ...
    def __hash__(self): ...
    def __eq__(self, other): ...



from _typeshed import ReadableBuffer

from pyasn1.type.base import Asn1Item

from ..protocol.rfc4511 import ExtendedRequest

def extended_operation(
    request_name, request_value: Asn1Item | ReadableBuffer | None = None, no_encode: bool | None = None
) -> ExtendedRequest: ...
def extended_request_to_dict(request): ...
def extended_response_to_dict(response): ...
def intermediate_response_to_dict(response): ...
def extended_response_to_dict_fast(response): ...
def intermediate_response_to_dict_fast(response): ...



from decimal import Decimal

from braintree.attribute_getter import AttributeGetter

class DisbursementDetail(AttributeGetter):
    settlement_amount: Decimal | None
    settlement_currency_exchange_rate: Decimal | None
    def __init__(self, attributes) -> None: ...
    @property
    def is_valid(self): ...



from typing import Any
from typing_extensions import TypeAlias

_Data: TypeAlias = str | bytes | bytearray

class BaseSerializer:
    content_types: list[str] | None
    key: str | None
    def get_content_type(self) -> str: ...
    def loads(self, data: _Data) -> Any: ...
    def dumps(self, data: _Data) -> Any: ...

class JsonSerializer(BaseSerializer):
    content_types: list[str]
    key: str

class YamlSerializer(BaseSerializer):
    content_types: list[str]
    key: str

class Serializer:
    serializers: list[BaseSerializer]
    default: str
    def __init__(self, default: str | None = None, serializers: list[BaseSerializer] | None = None) -> None: ...
    def get_serializer(self, name: str | None = None, content_type: str | None = None) -> BaseSerializer: ...
    def loads(self, data: _Data, format: str | None = None) -> Any: ...
    def dumps(self, data: _Data, format: str | None = None) -> Any: ...
    def get_content_type(self, format: str | None = None) -> str: ...



from _typeshed import Incomplete
from typing import ClassVar

from ..core import WesternCalendar

class Mexico(WesternCalendar):
    FIXED_HOLIDAYS: Incomplete
    include_labour_day: ClassVar[bool]
    def get_variable_days(self, year): ...
    def get_calendar_holidays(self, year): ...



import re
from _typeshed import StrOrBytesPath, SupportsLenAndGetItem, Unused
from collections import defaultdict
from collections.abc import Collection, Iterable
from io import BytesIO
from typing import Literal
from typing_extensions import Self, TypeAlias

FREE_NS: str
types: dict[str, MIMEtype]
exts: Unused | None  # This appears to be unused.
globs: GlobDB | None
literals: Unused | None  # This appears to be unused.
magic: MagicDB | None
PY3: Literal[True]

_MimeTypeWeightPair: TypeAlias = tuple[MIMEtype, int]

def lookup(media: str, subtype: str | None = None) -> MIMEtype: ...

class MIMEtype:
    def __new__(cls, media: str, subtype: str | None = None) -> Self: ...
    def get_comment(self) -> str: ...
    def canonical(self) -> Self: ...
    def inherits_from(self) -> set[MIMEtype]: ...
    def __hash__(self) -> int: ...

class UnknownMagicRuleFormat(ValueError): ...
class DiscardMagicRules(Exception): ...

class MagicRule:
    also: MagicRule | MagicMatchAny | None
    start: int
    value: bytes
    mask: bytes | None
    word: int
    range: int
    def __init__(self, start: int, value: bytes, mask: bytes, word: int, range: int) -> None: ...
    rule_ending_re: re.Pattern[str]
    @classmethod
    def from_file(cls, f: BytesIO) -> tuple[int, MagicRule]: ...
    def maxlen(self) -> int: ...
    def match(self, buffer: SupportsLenAndGetItem[bytes]) -> bool: ...
    def match0(self, buffer: SupportsLenAndGetItem[bytes]) -> bool: ...

class MagicMatchAny:
    rules: Collection[MagicRule]
    def __init__(self, rules: Iterable[MagicRule]) -> None: ...
    def match(self, buffer: SupportsLenAndGetItem[bytes]) -> bool: ...
    def maxlen(self) -> int: ...
    @classmethod
    def from_file(cls, f: BytesIO) -> MagicMatchAny | MagicRule | None: ...
    @classmethod
    def from_rule_tree(cls, tree: list[MagicRule]) -> MagicMatchAny | MagicRule | None: ...

class MagicDB:
    bytype: defaultdict[MIMEtype, list[tuple[int, MagicRule]]]
    def __init__(self) -> None: ...
    def merge_file(self, fname: StrOrBytesPath) -> None: ...
    alltypes: list[tuple[int, MIMEtype, MagicRule]]
    maxlen: int
    def finalise(self) -> None: ...
    def match_data(
        self, data: bytes, max_pri: int = 100, min_pri: int = 0, possible: Iterable[MIMEtype] | None = None
    ) -> MIMEtype: ...
    def match(
        self, path: StrOrBytesPath, max_pri: int = 100, min_pri: int = 0, possible: Iterable[MIMEtype] | None = None
    ) -> MIMEtype: ...

class GlobDB:
    allglobs: defaultdict[MIMEtype, list[tuple[int, str, str]]]
    def __init__(self) -> None: ...
    def merge_file(self, path: StrOrBytesPath) -> None: ...
    exts: defaultdict[str, list[MIMEtype | int]]  # Actually list[MIMEtype, int], but that's not valid.
    cased_exts: defaultdict[str, list[MIMEtype | int]]  # Actually list[MIMEtype, int], but that's not valid.
    globs: list[tuple[re.Pattern[str], MIMEtype, int]]
    literals: dict[str, _MimeTypeWeightPair]
    cased_literals: dict[str, _MimeTypeWeightPair]
    def finalise(self) -> None: ...
    def first_match(self, path: StrOrBytesPath) -> _MimeTypeWeightPair | None: ...
    def all_matches(self, path: StrOrBytesPath) -> list[_MimeTypeWeightPair]: ...

text: MIMEtype
octet_stream: MIMEtype
inode_block: MIMEtype
inode_char: MIMEtype
inode_dir: MIMEtype
inode_fifo: MIMEtype
inode_socket: MIMEtype
inode_symlink: MIMEtype
inode_door: MIMEtype
app_exe: MIMEtype

def update_cache() -> None: ...
def get_type_by_name(path: StrOrBytesPath) -> _MimeTypeWeightPair | None: ...
def get_type_by_contents(path: StrOrBytesPath, max_pri: int = 100, min_pri: int = 0) -> MIMEtype: ...
def get_type_by_data(data: bytes, max_pri: int = 100, min_pri: int = 0) -> MIMEtype: ...
def get_type(path: StrOrBytesPath, follow: bool = True, name_pri: int = 100) -> MIMEtype: ...
def get_type2(path: StrOrBytesPath, follow: bool = True) -> MIMEtype: ...
def is_text_file(path: StrOrBytesPath) -> bool: ...
def get_extensions(mimetype: MIMEtype) -> set[str]: ...
def install_mime_info(application: str, package_file: StrOrBytesPath) -> None: ...



from Xlib.keysymdef.latin1 import *
from Xlib.keysymdef.miscellany import *
from Xlib.X import NoSymbol as NoSymbol

def string_to_keysym(keysym: str) -> int: ...
def load_keysym_group(group: str) -> None: ...
def keysym_to_string(keysym: int) -> str | None: ...



from _typeshed import Incomplete

class QRColorMask:
    back_color: Incomplete
    has_transparency: bool
    paint_color = back_color
    def initialize(self, styledPilImage, image) -> None: ...
    def apply_mask(self, image) -> None: ...
    def get_fg_pixel(self, image, x, y) -> None: ...
    def get_bg_pixel(self, image, x, y): ...
    def interp_num(self, n1, n2, norm): ...
    def interp_color(self, col1, col2, norm): ...
    def extrap_num(self, n1, n2, interped_num): ...
    def extrap_color(self, col1, col2, interped_color): ...

class SolidFillColorMask(QRColorMask):
    back_color: Incomplete
    front_color: Incomplete
    has_transparency: Incomplete
    def __init__(self, back_color=(255, 255, 255), front_color=(0, 0, 0)) -> None: ...
    def apply_mask(self, image) -> None: ...
    def get_fg_pixel(self, image, x, y): ...

class RadialGradiantColorMask(QRColorMask):
    back_color: Incomplete
    center_color: Incomplete
    edge_color: Incomplete
    has_transparency: Incomplete
    def __init__(self, back_color=(255, 255, 255), center_color=(0, 0, 0), edge_color=(0, 0, 255)) -> None: ...
    def get_fg_pixel(self, image, x, y): ...

class SquareGradiantColorMask(QRColorMask):
    back_color: Incomplete
    center_color: Incomplete
    edge_color: Incomplete
    has_transparency: Incomplete
    def __init__(self, back_color=(255, 255, 255), center_color=(0, 0, 0), edge_color=(0, 0, 255)) -> None: ...
    def get_fg_pixel(self, image, x, y): ...

class HorizontalGradiantColorMask(QRColorMask):
    back_color: Incomplete
    left_color: Incomplete
    right_color: Incomplete
    has_transparency: Incomplete
    def __init__(self, back_color=(255, 255, 255), left_color=(0, 0, 0), right_color=(0, 0, 255)) -> None: ...
    def get_fg_pixel(self, image, x, y): ...

class VerticalGradiantColorMask(QRColorMask):
    back_color: Incomplete
    top_color: Incomplete
    bottom_color: Incomplete
    has_transparency: Incomplete
    def __init__(self, back_color=(255, 255, 255), top_color=(0, 0, 0), bottom_color=(0, 0, 255)) -> None: ...
    def get_fg_pixel(self, image, x, y): ...

class ImageColorMask(QRColorMask):
    back_color: Incomplete
    color_img: Incomplete
    has_transparency: Incomplete
    def __init__(
        self, back_color=(255, 255, 255), color_mask_path: Incomplete | None = None, color_mask_image: Incomplete | None = None
    ) -> None: ...
    paint_color: Incomplete
    def initialize(self, styledPilImage, image) -> None: ...
    def get_fg_pixel(self, image, x, y): ...



from _typeshed import Incomplete
from typing import Any

from .base import Client as Client

class MobileApplicationClient(Client):
    response_type: str
    def prepare_request_uri(
        self,
        uri,
        redirect_uri: Incomplete | None = None,
        scope: Incomplete | None = None,
        state: Incomplete | None = None,
        **kwargs,
    ): ...
    token: Any
    def parse_request_uri_response(self, uri, state: Incomplete | None = None, scope: Incomplete | None = None): ...



from _typeshed import ConvertibleToFloat, ConvertibleToInt, Incomplete, Unused
from typing import ClassVar, Literal
from typing_extensions import TypeAlias

from openpyxl.descriptors.base import Alias, Integer, MinMax, NoneSet, Typed, _ConvertibleToBool
from openpyxl.descriptors.excel import ExtensionList
from openpyxl.descriptors.nested import EmptyTag, NestedInteger, NestedNoneSet, _NestedNoneSetParam
from openpyxl.descriptors.serialisable import Serialisable
from openpyxl.drawing.colors import ColorChoice, ColorChoiceDescriptor
from openpyxl.drawing.fill import GradientFillProperties, PatternFillProperties

from ..xml._functions_overloads import _HasTagAndGet

_LineEndPropertiesType: TypeAlias = Literal["none", "triangle", "stealth", "diamond", "oval", "arrow"]
_LineEndPropertiesWLen: TypeAlias = Literal["sm", "med", "lg"]
_LinePropertiesCap: TypeAlias = Literal["rnd", "sq", "flat"]
_LinePropertiesCmpd: TypeAlias = Literal["sng", "dbl", "thickThin", "thinThick", "tri"]
_LinePropertiesAlgn: TypeAlias = Literal["ctr", "in"]
_LinePropertiesPrstDash: TypeAlias = Literal[
    "solid", "dot", "dash", "lgDash", "dashDot", "lgDashDot", "lgDashDotDot", "sysDash", "sysDot", "sysDashDot", "sysDashDotDot"
]

class LineEndProperties(Serialisable):
    tagname: ClassVar[str]
    namespace: ClassVar[str]
    type: NoneSet[_LineEndPropertiesType]
    w: NoneSet[_LineEndPropertiesWLen]
    len: NoneSet[_LineEndPropertiesWLen]
    def __init__(
        self,
        type: _LineEndPropertiesType | Literal["none"] | None = None,
        w: _LineEndPropertiesWLen | Literal["none"] | None = None,
        len: _LineEndPropertiesWLen | Literal["none"] | None = None,
    ) -> None: ...

class DashStop(Serialisable):
    tagname: ClassVar[str]
    namespace: ClassVar[str]
    d: Integer[Literal[False]]
    length: Alias
    sp: Integer[Literal[False]]
    space: Alias
    def __init__(self, d: ConvertibleToInt = 0, sp: ConvertibleToInt = 0) -> None: ...

class DashStopList(Serialisable):
    ds: Incomplete
    def __init__(self, ds: Incomplete | None = None) -> None: ...

class LineProperties(Serialisable):
    tagname: ClassVar[str]
    namespace: ClassVar[str]
    w: MinMax[float, Literal[True]]
    width: Alias
    cap: NoneSet[_LinePropertiesCap]
    cmpd: NoneSet[_LinePropertiesCmpd]
    algn: NoneSet[_LinePropertiesAlgn]
    noFill: EmptyTag[Literal[False]]
    solidFill: ColorChoiceDescriptor
    gradFill: Typed[GradientFillProperties, Literal[True]]
    pattFill: Typed[PatternFillProperties, Literal[True]]
    prstDash: NestedNoneSet[_LinePropertiesPrstDash]
    dashStyle: Alias
    custDash: Typed[DashStop, Literal[True]]
    round: EmptyTag[Literal[False]]
    bevel: EmptyTag[Literal[False]]
    miter: NestedInteger[Literal[True]]
    headEnd: Typed[LineEndProperties, Literal[True]]
    tailEnd: Typed[LineEndProperties, Literal[True]]
    extLst: Typed[ExtensionList, Literal[True]]
    __elements__: ClassVar[tuple[str, ...]]
    def __init__(
        self,
        w: ConvertibleToFloat | None = None,
        cap: _LinePropertiesCap | Literal["none"] | None = None,
        cmpd: _LinePropertiesCmpd | Literal["none"] | None = None,
        algn: _LinePropertiesAlgn | Literal["none"] | None = None,
        noFill: _HasTagAndGet[_ConvertibleToBool] | _ConvertibleToBool = None,
        solidFill: str | ColorChoice | None = None,
        gradFill: GradientFillProperties | None = None,
        pattFill: PatternFillProperties | None = None,
        prstDash: _NestedNoneSetParam[_LinePropertiesPrstDash] = None,
        custDash: DashStop | None = None,
        round: _HasTagAndGet[_ConvertibleToBool] | _ConvertibleToBool = None,
        bevel: _HasTagAndGet[_ConvertibleToBool] | _ConvertibleToBool = None,
        miter: _HasTagAndGet[ConvertibleToInt | None] | ConvertibleToInt | None = None,
        headEnd: LineEndProperties | None = None,
        tailEnd: LineEndProperties | None = None,
        extLst: Unused = None,
    ) -> None: ...



from _typeshed import Incomplete

import pika.compat

class AMQPConnectorException(Exception): ...
class AMQPConnectorStackTimeout(AMQPConnectorException): ...
class AMQPConnectorAborted(AMQPConnectorException): ...
class AMQPConnectorWrongState(AMQPConnectorException): ...

class AMQPConnectorPhaseErrorBase(AMQPConnectorException):
    exception: Incomplete
    def __init__(self, exception, *args) -> None: ...

class AMQPConnectorSocketConnectError(AMQPConnectorPhaseErrorBase): ...
class AMQPConnectorTransportSetupError(AMQPConnectorPhaseErrorBase): ...
class AMQPConnectorAMQPHandshakeError(AMQPConnectorPhaseErrorBase): ...
class AMQPConnectionWorkflowAborted(AMQPConnectorException): ...
class AMQPConnectionWorkflowWrongState(AMQPConnectorException): ...

class AMQPConnectionWorkflowFailed(AMQPConnectorException):
    exceptions: Incomplete
    def __init__(self, exceptions, *args) -> None: ...

class AMQPConnector:
    def __init__(self, conn_factory, nbio) -> None: ...
    def start(self, addr_record, conn_params, on_done) -> None: ...
    def abort(self) -> None: ...

class AbstractAMQPConnectionWorkflow(pika.compat.AbstractBase):
    def start(self, connection_configs, connector_factory, native_loop, on_done) -> None: ...
    def abort(self) -> None: ...

class AMQPConnectionWorkflow(AbstractAMQPConnectionWorkflow):
    def __init__(self, _until_first_amqp_attempt: bool = False) -> None: ...
    def set_io_services(self, nbio) -> None: ...
    def start(self, connection_configs, connector_factory, native_loop, on_done) -> None: ...
    def abort(self) -> None: ...



from _typeshed import Incomplete, SupportsKeysAndGetItem, Unused
from collections.abc import Callable, Iterable
from html.parser import HTMLParser
from logging import Logger
from typing import ClassVar, Final

from fpdf import FPDF

__author__: Final[str]
__copyright__: Final[str]

LOGGER: Logger
BULLET_WIN1252: Final[str]
DEFAULT_HEADING_SIZES: dict[str, int]

COLOR_DICT: Final[dict[str, str]]

def color_as_decimal(color: str | None = "#000000") -> tuple[int, int, int] | None: ...

class HTML2FPDF(HTMLParser):
    HTML_UNCLOSED_TAGS: ClassVar[tuple[str, ...]]

    pdf: FPDF
    image_map: Incomplete
    li_tag_indent: int
    dd_tag_indent: int
    ul_bullet_char: str
    heading_sizes: dict[str, int]
    pre_code_font: str
    warn_on_tags_not_matching: bool
    style: Incomplete
    font_size: Incomplete
    follows_trailing_space: bool
    follows_heading: bool
    href: str
    align: str
    page_links: Incomplete
    font_stack: Incomplete
    indent: int
    bullet: Incomplete
    font_color: Incomplete
    table: Incomplete
    table_col_width: Incomplete
    table_col_index: Incomplete
    td: Incomplete
    th: Incomplete
    tr: Incomplete
    thead: Incomplete
    tfoot: Incomplete
    tr_index: Incomplete
    theader: Incomplete
    tfooter: Incomplete
    theader_out: bool
    table_row_height: int
    heading_level: Incomplete
    heading_above: float
    heading_below: float

    # Not initialized in __init__:
    font_face: Incomplete
    h: float

    def __init__(
        self,
        pdf: FPDF,
        image_map: Callable[[str], str] | None = None,
        li_tag_indent: int = 5,
        dd_tag_indent: int = 10,
        table_line_separators: bool = False,
        ul_bullet_char: str = "\x95",
        heading_sizes: SupportsKeysAndGetItem[str, int] | Iterable[tuple[str, int]] | None = None,
        pre_code_font: str = "courier",
        warn_on_tags_not_matching: bool = True,
        **_: Unused,
    ): ...
    def handle_data(self, data) -> None: ...
    def handle_starttag(self, tag, attrs) -> None: ...
    def handle_endtag(self, tag) -> None: ...
    def set_font(self, face: Incomplete | None = None, size: Incomplete | None = None, set_default: bool = False) -> None: ...
    def set_style(self, tag: Incomplete | None = None, enable: bool = False) -> None: ...
    def set_text_color(self, r: Incomplete | None = None, g: int = 0, b: int = 0) -> None: ...
    def put_link(self, text) -> None: ...
    def render_toc(self, pdf, outline) -> None: ...
    def error(self, message: str) -> None: ...

class HTMLMixin:
    def __init__(self, *args, **kwargs) -> None: ...



from _typeshed import Incomplete
from typing import Any

from .base import BaseEndpoint as BaseEndpoint

log: Any

class AuthorizationEndpoint(BaseEndpoint):
    def __init__(self, default_response_type, default_token_type, response_types) -> None: ...
    @property
    def response_types(self): ...
    @property
    def default_response_type(self): ...
    @property
    def default_response_type_handler(self): ...
    @property
    def default_token_type(self): ...
    def create_authorization_response(
        self,
        uri,
        http_method: str = "GET",
        body: Incomplete | None = None,
        headers: Incomplete | None = None,
        scopes: Incomplete | None = None,
        credentials: Incomplete | None = None,
    ): ...
    def validate_authorization_request(
        self, uri, http_method: str = "GET", body: Incomplete | None = None, headers: Incomplete | None = None
    ): ...



from _typeshed import Incomplete

def SeriesFactory(
    values,
    xvalues: Incomplete | None = None,
    zvalues: Incomplete | None = None,
    title: object = None,
    title_from_data: bool = False,
): ...



import datetime
import io
from _typeshed import ExcInfo, ReadableBuffer, SupportsItems, SupportsKeysAndGetItem, SupportsNoArgReadline, SupportsRead
from _typeshed.wsgi import WSGIApplication, WSGIEnvironment
from cgi import FieldStorage
from collections.abc import Iterable, Mapping
from re import Pattern
from tempfile import _TemporaryFileWrapper
from typing import IO, Any, ClassVar, Literal, Protocol, TypedDict, TypeVar, overload
from typing_extensions import Self, TypeAlias

from webob.acceptparse import _AcceptCharsetProperty, _AcceptEncodingProperty, _AcceptLanguageProperty, _AcceptProperty
from webob.byterange import Range
from webob.cachecontrol import _RequestCacheControl
from webob.cookies import RequestCookies
from webob.descriptors import _AsymmetricProperty, _AsymmetricPropertyWithDelete, _authorization, _DateProperty
from webob.etag import IfRange, IfRangeDate, _ETagProperty
from webob.headers import EnvironHeaders
from webob.multidict import GetDict, MultiDict, NestedMultiDict, NoVars
from webob.response import Response, _HTTPHeader

_T = TypeVar("_T")
_HTTPMethod: TypeAlias = Literal["GET", "HEAD", "POST", "PUT", "DELETE", "PATCH"]
_ListOrTuple: TypeAlias = list[_T] | tuple[_T, ...]

class _SupportsReadAndNoArgReadline(SupportsRead[bytes], SupportsNoArgReadline[bytes], Protocol): ...

class _RequestCacheControlDict(TypedDict, total=False):
    max_stale: int
    min_stale: int
    only_if_cached: bool
    no_cache: Literal[True] | str
    no_store: bool
    no_transform: bool
    max_age: int

class _FieldStorageWithFile(FieldStorage):
    file: IO[bytes]
    filename: str

class _NoDefault: ...

NoDefault: _NoDefault

class BaseRequest:
    request_body_tempfile_limit: ClassVar[int]
    environ: WSGIEnvironment
    method: _HTTPMethod
    def __init__(self, environ: WSGIEnvironment, **kw: Any) -> None: ...
    @overload
    def encget(self, key: str, default: _T, encattr: str | None = None) -> str | _T: ...
    @overload
    def encget(self, key: str, *, encattr: str | None = None) -> str: ...
    def encset(self, key: str, val: str, encattr: str | None = None) -> None: ...
    @property
    def charset(self) -> str | None: ...
    def decode(self, charset: str | None = None, errors: str = "strict") -> Self: ...
    @property
    def body_file(self) -> SupportsRead[bytes]: ...
    @body_file.setter
    def body_file(self, value: SupportsRead[bytes]) -> None: ...
    content_length: int | None
    body_file_raw: SupportsRead[bytes]
    is_body_seekable: bool
    @property
    def body_file_seekable(self) -> IO[bytes]: ...
    url_encoding: str
    @property
    def scheme(self) -> str | None: ...
    @scheme.setter
    def scheme(self, value: str | None) -> None: ...
    @property
    def http_version(self) -> str | None: ...
    @http_version.setter
    def http_version(self, value: str | None) -> None: ...
    remote_user: str | None
    remote_host: str | None
    remote_addr: str | None
    query_string: str
    @property
    def server_name(self) -> str | None: ...
    @server_name.setter
    def server_name(self, value: str | None) -> None: ...
    @property
    def server_port(self) -> int | None: ...
    @server_port.setter
    def server_port(self, value: int | None) -> None: ...
    script_name: str
    @property
    def path_info(self) -> str | None: ...
    @path_info.setter
    def path_info(self, value: str | None) -> None: ...
    uscript_name: str  # bw compat
    @property
    def upath_info(self) -> str | None: ...  # bw compat
    @upath_info.setter
    def upath_info(self, value: str | None) -> None: ...  # bw compat
    content_type: str | None
    headers: _AsymmetricProperty[EnvironHeaders, SupportsItems[str, str] | Iterable[tuple[str, str]]]
    @property
    def client_addr(self) -> str | None: ...
    @property
    def host_port(self) -> str: ...
    @property
    def host_url(self) -> str: ...
    @property
    def application_url(self) -> str: ...
    @property
    def path_url(self) -> str: ...
    @property
    def path(self) -> str: ...
    @property
    def path_qs(self) -> str: ...
    @property
    def url(self) -> str: ...
    def relative_url(self, other_url: str, to_application: bool = False) -> str: ...
    def path_info_pop(self, pattern: Pattern[str] | None = None) -> str | None: ...
    def path_info_peek(self) -> str | None: ...
    urlvars: dict[str, str]
    urlargs: tuple[str]
    @property
    def is_xhr(self) -> bool: ...
    host: str
    @property
    def domain(self) -> str: ...
    body: bytes
    json: Any
    json_body: Any
    text: str
    @property
    def POST(self) -> MultiDict[str, str | _FieldStorageWithFile] | NoVars: ...
    @property
    def GET(self) -> GetDict: ...
    @property
    def params(self) -> NestedMultiDict[str, str | _FieldStorageWithFile]: ...
    cookies: _AsymmetricProperty[RequestCookies, SupportsKeysAndGetItem[str, str] | Iterable[tuple[str, str]]]
    def copy(self) -> Self: ...
    def copy_get(self) -> Self: ...
    @property
    def is_body_readable(self) -> bool: ...
    @is_body_readable.setter
    def is_body_readable(self, flag: bool) -> None: ...
    def make_body_seekable(self) -> None: ...
    def copy_body(self) -> None: ...
    def make_tempfile(self) -> _TemporaryFileWrapper[bytes]: ...
    def remove_conditional_headers(
        self, remove_encoding: bool = True, remove_range: bool = True, remove_match: bool = True, remove_modified: bool = True
    ) -> None: ...
    accept: _AcceptProperty
    accept_charset: _AcceptCharsetProperty
    accept_encoding: _AcceptEncodingProperty
    accept_language: _AcceptLanguageProperty
    authorization: _AsymmetricPropertyWithDelete[_authorization | None, tuple[str, str | dict[str, str]] | list[Any] | str | None]
    cache_control: _AsymmetricPropertyWithDelete[
        _RequestCacheControl | None, _RequestCacheControl | _RequestCacheControlDict | str | None
    ]
    if_match: _ETagProperty
    if_none_match: _ETagProperty
    date: _DateProperty
    if_modified_since: _DateProperty
    if_unmodified_since: _DateProperty
    if_range: _AsymmetricPropertyWithDelete[
        IfRange | IfRangeDate | None, IfRange | IfRangeDate | datetime.datetime | datetime.date | str | None
    ]
    max_forwards: int | None
    pragma: str | None
    range: _AsymmetricPropertyWithDelete[Range | None, tuple[int, int | None] | list[int | None] | list[int] | str | None]
    referer: str | None
    referrer: str | None
    user_agent: str | None
    def as_bytes(self, skip_body: bool = False) -> bytes: ...
    def as_text(self) -> str: ...
    @classmethod
    def from_bytes(cls, b: bytes) -> Self: ...
    @classmethod
    def from_text(cls, s: str) -> Self: ...
    @classmethod
    def from_file(cls, fp: _SupportsReadAndNoArgReadline) -> Self: ...
    @overload
    def call_application(
        self, application: WSGIApplication, catch_exc_info: Literal[False] = False
    ) -> tuple[str, list[_HTTPHeader], Iterable[bytes]]: ...
    @overload
    def call_application(
        self, application: WSGIApplication, catch_exc_info: Literal[True]
    ) -> tuple[str, list[_HTTPHeader], Iterable[bytes], ExcInfo | None]: ...
    ResponseClass: type[Response]
    def send(self, application: WSGIApplication | None = None, catch_exc_info: bool = False) -> Response: ...
    get_response = send
    def make_default_send_app(self) -> WSGIApplication: ...
    @classmethod
    def blank(
        cls,
        path: str,
        environ: dict[str, None] | None = None,
        base_url: str | None = None,
        headers: Mapping[str, str] | None = None,
        POST: str | bytes | Mapping[Any, Any] | Mapping[Any, _ListOrTuple[Any]] | None = None,
        **kw: Any,
    ) -> Self: ...

class LegacyRequest(BaseRequest):
    @property
    def uscript_name(self) -> str: ...
    @uscript_name.setter
    def uscript_name(self, value: str) -> None: ...
    @property  # type:ignore[override]
    def upath_info(self) -> str: ...
    @upath_info.setter
    def upath_info(self, value: str) -> None: ...
    def encget(self, key: str, default: Any = ..., encattr: str | None = None) -> Any: ...

class AdhocAttrMixin:
    def __setattr__(self, attr: str, value: Any) -> None: ...
    def __getattr__(self, attr: str) -> Any: ...
    def __delattr__(self, attr: str) -> None: ...

class Request(AdhocAttrMixin, BaseRequest):
    # this is so Request doesn't count as callable, it's not very pretty
    # but we run into trouble with overlapping overloads in wsgify if we
    # don't exclude __call__ from arbitrary attribute access
    __call__: None

class DisconnectionError(IOError): ...

def environ_from_url(path: str) -> WSGIEnvironment: ...
def environ_add_POST(
    env: WSGIEnvironment,
    data: str | bytes | Mapping[Any, Any] | Mapping[Any, _ListOrTuple[Any]] | None,
    content_type: str | None = None,
) -> None: ...

class LimitedLengthFile(io.RawIOBase):
    file: SupportsRead[bytes]
    maxlen: int
    remaining: int
    def __init__(self, file: SupportsRead[bytes], maxlen: int) -> None: ...
    @staticmethod
    def readable() -> Literal[True]: ...
    def readinto(self, buff: ReadableBuffer) -> int: ...

class Transcoder:
    charset: str
    errors: str
    def __init__(self, charset: str, errors: str = "strict") -> None: ...
    def transcode_query(self, q: str) -> str: ...
    def transcode_fs(self, fs: FieldStorage, content_type: str) -> io.BytesIO: ...



from _typeshed import Incomplete
from typing import Any

from ..date import _DetectLanguagesFunction

RELATIVE_REG: Any

def date_is_relative(translation): ...

class _ExactLanguageSearch:
    loader: Any
    language: Any
    def __init__(self, loader) -> None: ...
    def get_current_language(self, shortname) -> None: ...
    def search(self, shortname, text, settings): ...
    @staticmethod
    def set_relative_base(substring, already_parsed): ...
    def choose_best_split(self, possible_parsed_splits, possible_substrings_splits): ...
    def split_by(self, item, original, splitter): ...
    def split_if_not_parsed(self, item, original): ...
    def parse_item(self, parser, item, translated_item, parsed, need_relative_base): ...
    def parse_found_objects(self, parser, to_parse, original, translated, settings): ...
    def search_parse(self, shortname, text, settings): ...

class DateSearchWithDetection:
    loader: Any
    available_language_map: Any
    search: Any
    def __init__(self) -> None: ...
    language_detector: Any
    def detect_language(
        self,
        text,
        languages,
        settings: Incomplete | None = None,
        detect_languages_function: _DetectLanguagesFunction | None = None,
    ): ...
    def search_dates(
        self,
        text,
        languages: Incomplete | None = None,
        settings: Incomplete | None = None,
        detect_languages_function: _DetectLanguagesFunction | None = None,
    ): ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def full_rary_tree(r, n, create_using: Incomplete | None = None): ...
@_dispatch
def balanced_tree(r, h, create_using: Incomplete | None = None): ...
@_dispatch
def barbell_graph(m1, m2, create_using: Incomplete | None = None): ...
@_dispatch
def binomial_tree(n, create_using: Incomplete | None = None): ...
@_dispatch
def complete_graph(n, create_using: Incomplete | None = None): ...
@_dispatch
def circular_ladder_graph(n, create_using: Incomplete | None = None): ...
@_dispatch
def circulant_graph(n, offsets, create_using: Incomplete | None = None): ...
@_dispatch
def cycle_graph(n, create_using: Incomplete | None = None): ...
@_dispatch
def dorogovtsev_goltsev_mendes_graph(n, create_using: Incomplete | None = None): ...
@_dispatch
def empty_graph(n: Incomplete | int = 0, create_using: Incomplete | None = None, default=...): ...
@_dispatch
def ladder_graph(n, create_using: Incomplete | None = None): ...
@_dispatch
def lollipop_graph(m, n, create_using: Incomplete | None = None): ...
@_dispatch
def null_graph(create_using: Incomplete | None = None): ...
@_dispatch
def path_graph(n, create_using: Incomplete | None = None): ...
@_dispatch
def star_graph(n, create_using: Incomplete | None = None): ...
@_dispatch
def trivial_graph(create_using: Incomplete | None = None): ...
@_dispatch
def turan_graph(n, r): ...
@_dispatch
def wheel_graph(n, create_using: Incomplete | None = None): ...
@_dispatch
def complete_multipartite_graph(*subset_sizes): ...



from _typeshed import Incomplete

from influxdb_client.domain.slack_notification_rule_base import SlackNotificationRuleBase

class SlackNotificationRule(SlackNotificationRuleBase):
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        type: str = "slack",
        channel: Incomplete | None = None,
        message_template: Incomplete | None = None,
        latest_completed: Incomplete | None = None,
        last_run_status: Incomplete | None = None,
        last_run_error: Incomplete | None = None,
        id: Incomplete | None = None,
        endpoint_id: Incomplete | None = None,
        org_id: Incomplete | None = None,
        task_id: Incomplete | None = None,
        owner_id: Incomplete | None = None,
        created_at: Incomplete | None = None,
        updated_at: Incomplete | None = None,
        status: Incomplete | None = None,
        name: Incomplete | None = None,
        sleep_until: Incomplete | None = None,
        every: Incomplete | None = None,
        offset: Incomplete | None = None,
        runbook_link: Incomplete | None = None,
        limit_every: Incomplete | None = None,
        limit: Incomplete | None = None,
        tag_rules: Incomplete | None = None,
        description: Incomplete | None = None,
        status_rules: Incomplete | None = None,
        labels: Incomplete | None = None,
        links: Incomplete | None = None,
    ) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



class SetuptoolsWarning(UserWarning):
    @classmethod
    def emit(
        cls,
        summary: str | None = None,
        details: str | None = None,
        due_date: tuple[int, int, int] | None = None,
        see_docs: str | None = None,
        see_url: str | None = None,
        stacklevel: int = 2,
        **kwargs,
    ) -> None: ...

class InformationOnly(SetuptoolsWarning): ...
class SetuptoolsDeprecationWarning(SetuptoolsWarning): ...



from _typeshed import Incomplete
from collections.abc import Callable, Sequence
from dataclasses import dataclass
from typing import Any, ClassVar
from typing_extensions import Self, TypeAlias

from matplotlib.axis import Ticker
from matplotlib.scale import ScaleBase
from matplotlib.ticker import Formatter, Locator
from matplotlib.units import ConversionInterface
from numpy.typing import ArrayLike, NDArray
from pandas import Series
from seaborn._core.typing import Default

TransFuncs: TypeAlias = tuple[Callable[[ArrayLike], ArrayLike], Callable[[ArrayLike], ArrayLike]]
Pipeline: TypeAlias = Sequence[Callable[[Any], Any] | None]

class Scale:
    values: tuple[Incomplete, ...] | str | list[Incomplete] | dict[Incomplete, Incomplete] | None
    def __post_init__(self) -> None: ...
    def tick(self) -> Self: ...
    def label(self) -> Self: ...
    def __call__(self, data: Series[Any]) -> ArrayLike: ...

@dataclass
class Boolean(Scale):
    values: tuple[Incomplete, ...] | list[Incomplete] | dict[Incomplete, Incomplete] | None = None
    def tick(self, locator: Locator | None = None) -> Self: ...
    def label(self, formatter: Formatter | None = None) -> Self: ...

@dataclass
class Nominal(Scale):
    values: tuple[Incomplete, ...] | str | list[Incomplete] | dict[Incomplete, Incomplete] | None = None
    order: list[Incomplete] | None = None
    def tick(self, locator: Locator | None = None) -> Self: ...
    def label(self, formatter: Formatter | None = None) -> Self: ...

@dataclass
class Ordinal(Scale): ...

@dataclass
class Discrete(Scale): ...

@dataclass
class ContinuousBase(Scale):
    values: tuple[Incomplete, ...] | str | None = None
    norm: tuple[Incomplete, ...] | None = None

@dataclass
class Continuous(ContinuousBase):
    values: tuple[Incomplete, ...] | str | None = None
    trans: str | TransFuncs | None = None
    def tick(
        self,
        locator: Locator | None = None,
        *,
        at: Sequence[float] | None = None,
        upto: int | None = None,
        count: int | None = None,
        every: float | None = None,
        between: tuple[float, float] | None = None,
        minor: int | None = None,
    ) -> Self: ...
    def label(
        self,
        formatter: Formatter | None = None,
        *,
        like: str | Callable[[float], str] | None = None,
        base: int | None | Default = ...,
        unit: str | None = None,
    ) -> Self: ...

@dataclass
class Temporal(ContinuousBase):
    trans: ClassVar[Incomplete]  # not sure it is a classvar but the runtime has no annotation so it is not a dataclass field
    def tick(self, locator: Locator | None = None, *, upto: int | None = None) -> Self: ...
    def label(self, formatter: Formatter | None = None, *, concise: bool = False) -> Self: ...

class PseudoAxis:
    axis_name: str
    converter: ConversionInterface | None
    units: Incomplete | None
    scale: ScaleBase
    major: Ticker
    minor: Ticker
    def __init__(self, scale: ScaleBase) -> None: ...
    def set_view_interval(self, vmin: float, vmax: float) -> None: ...
    def get_view_interval(self) -> tuple[float, float]: ...
    def set_data_interval(self, vmin: float, vmax: float) -> None: ...
    def get_data_interval(self) -> tuple[float, float]: ...
    def get_tick_space(self) -> int: ...
    def set_major_locator(self, locator: Locator) -> None: ...
    def set_major_formatter(self, formatter: Formatter) -> None: ...
    def set_minor_locator(self, locator: Locator) -> None: ...
    def set_minor_formatter(self, formatter: Formatter) -> None: ...
    def set_units(self, units: Incomplete) -> None: ...
    def update_units(self, x: Incomplete) -> None: ...
    def convert_units(self, x: Incomplete) -> Incomplete: ...
    def get_scale(self) -> ScaleBase: ...
    def get_majorticklocs(self) -> NDArray[Incomplete]: ...



from _typeshed import Incomplete

def format_smart_table(data, column_names): ...
def format_pretty_table(data, column_names: Incomplete | None = None, horizontal_bar: str = "-", vertical_bar: str = "|"): ...
def format_robust_table(data, column_names): ...
def format_rst_table(data, column_names: Incomplete | None = None): ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def is_threshold_graph(G): ...
@_dispatch
def find_threshold_graph(G, create_using: Incomplete | None = None): ...



import ast
from _typeshed import Incomplete
from argparse import Namespace
from collections.abc import Generator, Iterable
from typing import Any

__version__: str

PYTHON_VERSION: tuple[int, int, int]
CLASS_METHODS: frozenset[str]
METACLASS_BASES: frozenset[str]
METHOD_CONTAINER_NODES: set[ast.AST]

class NamingChecker:
    name: str
    version: str
    visitors: Any
    decorator_to_type: Any
    ignore_names: frozenset[str]
    parents: Any
    def __init__(self, tree: ast.AST, filename: str) -> None: ...
    @classmethod
    def add_options(cls, parser: Any) -> None: ...
    @classmethod
    def parse_options(cls, option: Namespace) -> None: ...
    def run(self) -> Generator[tuple[int, int, str, type[Any]], None, None]: ...
    def tag_class_functions(self, cls_node: ast.ClassDef) -> None: ...
    def set_function_nodes_types(self, nodes: Iterable[ast.AST], ismetaclass: bool, late_decoration: dict[str, str]) -> None: ...
    def __getattr__(self, name: str) -> Incomplete: ...  # incomplete (other attributes are normally not accessed)

def __getattr__(name: str) -> Incomplete: ...  # incomplete (other attributes are normally not accessed)



import multiprocessing
from _typeshed import Incomplete
from types import TracebackType

logger: Incomplete

class _PoisonPill: ...

class MultiprocessingWriter(multiprocessing.Process):
    __started__: bool
    __disposed__: bool
    kwargs: Incomplete
    client: Incomplete
    write_api: Incomplete
    queue_: Incomplete
    def __init__(self, **kwargs) -> None: ...
    def write(self, **kwargs) -> None: ...
    def run(self) -> None: ...
    def start(self) -> None: ...
    def terminate(self) -> None: ...
    def __enter__(self): ...
    def __exit__(
        self, exc_type: type[BaseException] | None, exc_value: BaseException | None, traceback: TracebackType | None
    ) -> None: ...
    def __del__(self) -> None: ...



from typing import Any

from yaml.error import MarkedYAMLError

class ParserError(MarkedYAMLError): ...

class Parser:
    DEFAULT_TAGS: Any
    current_event: Any
    yaml_version: Any
    tag_handles: Any
    states: Any
    marks: Any
    state: Any
    def __init__(self) -> None: ...
    def dispose(self): ...
    def check_event(self, *choices): ...
    def peek_event(self): ...
    def get_event(self): ...
    def parse_stream_start(self): ...
    def parse_implicit_document_start(self): ...
    def parse_document_start(self): ...
    def parse_document_end(self): ...
    def parse_document_content(self): ...
    def process_directives(self): ...
    def parse_block_node(self): ...
    def parse_flow_node(self): ...
    def parse_block_node_or_indentless_sequence(self): ...
    def parse_node(self, block=False, indentless_sequence=False): ...
    def parse_block_sequence_first_entry(self): ...
    def parse_block_sequence_entry(self): ...
    def parse_indentless_sequence_entry(self): ...
    def parse_block_mapping_first_key(self): ...
    def parse_block_mapping_key(self): ...
    def parse_block_mapping_value(self): ...
    def parse_flow_sequence_first_entry(self): ...
    def parse_flow_sequence_entry(self, first=False): ...
    def parse_flow_sequence_entry_mapping_key(self): ...
    def parse_flow_sequence_entry_mapping_value(self): ...
    def parse_flow_sequence_entry_mapping_end(self): ...
    def parse_flow_mapping_first_key(self): ...
    def parse_flow_mapping_key(self, first=False): ...
    def parse_flow_mapping_value(self): ...
    def parse_flow_mapping_empty_value(self): ...
    def process_empty_scalar(self, mark): ...



text_type = str

class Crypto:
    @staticmethod
    def sha1_hmac_hash(secret_key, content): ...
    @staticmethod
    def sha256_hmac_hash(secret_key, content): ...
    @staticmethod
    def secure_compare(left, right): ...



from _typeshed import Incomplete

class PaymentMethodNonceGateway:
    gateway: Incomplete
    config: Incomplete
    def __init__(self, gateway) -> None: ...
    def create(self, payment_method_token, params=...): ...
    def find(self, payment_method_nonce): ...



from logging import Logger
from typing import Any

from ._types import Reader

__version__: str
logger: Logger

def process_file(
    fh: Reader,
    stop_tag: str = "UNDEF",
    details: bool = True,
    strict: bool = False,
    debug: bool = False,
    truncate_tags: bool = True,
    auto_seek: bool = True,
) -> dict[str, Any]: ...



from _typeshed import Incomplete, Unused
from typing import ClassVar, Literal

from openpyxl.chart.data_source import StrRef
from openpyxl.descriptors.base import Alias, Typed
from openpyxl.descriptors.serialisable import Serialisable
from openpyxl.drawing.text import ListStyle, RichTextProperties
from openpyxl.xml.functions import Element

class RichText(Serialisable):
    tagname: ClassVar[str]
    bodyPr: Typed[RichTextProperties, Literal[False]]
    properties: Alias
    lstStyle: Typed[ListStyle, Literal[True]]
    p: Incomplete
    paragraphs: Alias
    __elements__: ClassVar[tuple[str, ...]]
    def __init__(
        self, bodyPr: RichTextProperties | None = None, lstStyle: ListStyle | None = None, p: Incomplete | None = None
    ) -> None: ...

class Text(Serialisable):
    tagname: ClassVar[str]
    strRef: Typed[StrRef, Literal[True]]
    rich: Typed[RichText, Literal[True]]
    __elements__: ClassVar[tuple[str, ...]]
    def __init__(self, strRef: StrRef | None = None, rich: RichText | None = None) -> None: ...
    def to_tree(self, tagname: str | None = None, idx: Unused = None, namespace: str | None = None) -> Element: ...



import abc
from _typeshed import Incomplete
from typing import Any
from typing_extensions import TypeAlias

from qrcode.image.styles.moduledrawers.base import QRModuleDrawer
from qrcode.main import QRCode

DrawerAliases: TypeAlias = dict[str, tuple[type[QRModuleDrawer], dict[str, Any]]]

class BaseImage(metaclass=abc.ABCMeta):
    kind: str | None
    allowed_kinds: tuple[str] | None
    needs_context: bool
    needs_processing: bool
    needs_drawrect: bool
    border: Incomplete
    width: Incomplete
    box_size: Incomplete
    pixel_size: Incomplete
    modules: Incomplete
    def __init__(self, border, width, box_size, *args, **kwargs) -> None: ...
    @abc.abstractmethod
    def drawrect(self, row, col): ...
    def drawrect_context(self, row: int, col: int, qr: QRCode[Incomplete]): ...
    def process(self) -> None: ...
    @abc.abstractmethod
    def save(self, stream, kind: Incomplete | None = None): ...
    def pixel_box(self, row, col): ...
    @abc.abstractmethod
    def new_image(self, **kwargs) -> Any: ...
    def init_new_image(self) -> None: ...
    def get_image(self, **kwargs): ...
    def check_kind(self, kind, transform: Incomplete | None = None): ...
    def is_eye(self, row: int, col: int): ...

class BaseImageWithDrawer(BaseImage, metaclass=abc.ABCMeta):
    default_drawer_class: type[QRModuleDrawer]
    drawer_aliases: DrawerAliases
    def get_default_module_drawer(self) -> QRModuleDrawer: ...
    def get_default_eye_drawer(self) -> QRModuleDrawer: ...
    needs_context: bool
    module_drawer: QRModuleDrawer
    eye_drawer: QRModuleDrawer
    def __init__(
        self, *args, module_drawer: QRModuleDrawer | str | None = None, eye_drawer: QRModuleDrawer | str | None = None, **kwargs
    ) -> None: ...
    def get_drawer(self, drawer: QRModuleDrawer | str | None) -> QRModuleDrawer | None: ...
    def init_new_image(self): ...
    def drawrect_context(self, row: int, col: int, qr: QRCode[Incomplete]): ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def is_tournament(G): ...
@_dispatch
def hamiltonian_path(G): ...
@_dispatch
def random_tournament(n, seed: Incomplete | None = None): ...
@_dispatch
def score_sequence(G): ...
@_dispatch
def is_reachable(G, s, t): ...
@_dispatch
def is_strongly_connected(G): ...



import concurrent.futures
from collections.abc import Callable
from typing import Any, Generic, TypeVar
from typing_extensions import ParamSpec, TypeAlias

from gevent._threading import Queue
from gevent._types import _AsyncWatcher, _Watcher
from gevent.event import AsyncResult, _OptExcInfo, _ValueSource
from gevent.greenlet import Greenlet
from gevent.hub import Hub
from gevent.pool import GroupMappingMixin

_T = TypeVar("_T")
_P = ParamSpec("_P")
_TaskItem: TypeAlias = tuple[Callable[..., Any], tuple[Any, ...], dict[str, Any], ThreadResult[Any]]
_Receiver: TypeAlias = Callable[[_ValueSource[_T]], object]

class ThreadPool(GroupMappingMixin):
    hub: Hub
    pid: int
    manager: Greenlet[..., Any] | None
    task_queue: Queue[_TaskItem]
    fork_watcher: _Watcher
    def __init__(self, maxsize: int, hub: Hub | None = None, idle_task_timeout: int = -1) -> None: ...
    @property
    def maxsize(self) -> int: ...
    @maxsize.setter
    def maxsize(self, value: int) -> None: ...
    @property
    def size(self) -> int: ...
    @size.setter
    def size(self, value: int) -> None: ...
    def __len__(self) -> int: ...
    def join(self) -> None: ...
    def kill(self) -> None: ...
    def adjust(self) -> None: ...
    def spawn(self, func: Callable[_P, _T], *args: _P.args, **kwargs: _P.kwargs) -> AsyncResult[_T]: ...  # type: ignore[override]

class ThreadResult(Generic[_T]):
    receiver: _Receiver[_T]
    hub: Hub
    context: object | None
    value: _T | None
    exc_info: _OptExcInfo | tuple[()]
    async_watcher: _AsyncWatcher
    def __init__(self, receiver: _Receiver[_T], hub: Hub, call_when_ready: Callable[[], object]) -> None: ...
    @property
    def exception(self) -> BaseException | None: ...
    def destroy_in_main_thread(self) -> None: ...
    def set(self, value: _T) -> None: ...
    def handle_error(self, context: object, exc_info: _OptExcInfo) -> None: ...
    def successful(self) -> bool: ...

class ThreadPoolExecutor(concurrent.futures.ThreadPoolExecutor):
    kill = concurrent.futures.ThreadPoolExecutor.shutdown



from _typeshed import Incomplete

from antlr4.tree.ParseTreePatternMatcher import ParseTreePatternMatcher as ParseTreePatternMatcher
from antlr4.tree.Tree import ParseTree as ParseTree
from antlr4.xpath.XPathLexer import XPathLexer as XPathLexer

class ParseTreePattern:
    matcher: Incomplete
    patternRuleIndex: Incomplete
    pattern: Incomplete
    patternTree: Incomplete
    def __init__(self, matcher: ParseTreePatternMatcher, pattern: str, patternRuleIndex: int, patternTree: ParseTree) -> None: ...
    def match(self, tree: ParseTree): ...
    def matches(self, tree: ParseTree): ...
    def findAll(self, tree: ParseTree, xpath: str): ...



from _typeshed import Incomplete
from typing import ClassVar

from .core import UnitedStates

class WestVirginia(UnitedStates):
    include_thanksgiving_friday: ClassVar[bool]
    include_election_day_even: ClassVar[bool]
    election_day_label: ClassVar[str]
    west_virginia_include_christmas_eve: ClassVar[bool]
    west_virginia_include_nye: ClassVar[bool]
    FIXED_HOLIDAYS: Incomplete
    shift_exceptions: Incomplete
    def get_fixed_holidays(self, year): ...



from _typeshed import Incomplete
from collections.abc import Generator

from networkx.algorithms.flow import edmonds_karp
from networkx.utils.backends import _dispatch

__all__ = ["edge_disjoint_paths", "node_disjoint_paths"]

default_flow_func = edmonds_karp

@_dispatch
def edge_disjoint_paths(
    G,
    s,
    t,
    flow_func: Incomplete | None = None,
    cutoff: Incomplete | None = None,
    auxiliary: Incomplete | None = None,
    residual: Incomplete | None = None,
) -> Generator[Incomplete, None, None]: ...
@_dispatch
def node_disjoint_paths(
    G,
    s,
    t,
    flow_func: Incomplete | None = None,
    cutoff: Incomplete | None = None,
    auxiliary: Incomplete | None = None,
    residual: Incomplete | None = None,
) -> Generator[Incomplete, None, None]: ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def eigenvector_centrality(
    G, max_iter: int = 100, tol: float = 1e-06, nstart: Incomplete | None = None, weight: Incomplete | None = None
): ...
@_dispatch
def eigenvector_centrality_numpy(G, weight: Incomplete | None = None, max_iter: int = 50, tol: float = 0): ...



from _typeshed import Incomplete
from typing import ClassVar

from ..core import WesternCalendar

class Canada(WesternCalendar):
    FIXED_HOLIDAYS: Incomplete
    shift_new_years_day: ClassVar[bool]
    def get_variable_days(self, year): ...

class LateFamilyDayMixin:
    def get_family_day(self, year, label: str = "Family Day"): ...

class VictoriaDayMixin:
    def get_victoria_day(self, year): ...

class AugustCivicHolidayMixin:
    def get_civic_holiday(self, year, label: str = "Civic Holiday"): ...

class ThanksgivingMixin:
    def get_thanksgiving(self, year): ...

class BoxingDayMixin:
    def get_boxing_day(self, year): ...

class StJeanBaptisteMixin:
    def get_st_jean(self, year): ...

class RemembranceDayShiftMixin:
    def get_remembrance_day(self, year): ...

class Ontario(BoxingDayMixin, ThanksgivingMixin, VictoriaDayMixin, LateFamilyDayMixin, AugustCivicHolidayMixin, Canada):
    include_good_friday: ClassVar[bool]
    def get_variable_days(self, year): ...

class Quebec(VictoriaDayMixin, StJeanBaptisteMixin, ThanksgivingMixin, Canada):
    include_easter_monday: ClassVar[bool]
    def get_variable_days(self, year): ...

class BritishColumbia(VictoriaDayMixin, AugustCivicHolidayMixin, ThanksgivingMixin, Canada):
    include_good_friday: ClassVar[bool]
    FIXED_HOLIDAYS: Incomplete
    def get_family_day(self, year): ...
    def get_variable_days(self, year): ...

class Alberta(LateFamilyDayMixin, VictoriaDayMixin, ThanksgivingMixin, Canada):
    include_good_friday: ClassVar[bool]
    FIXED_HOLIDAYS: Incomplete
    def get_variable_days(self, year): ...

class Saskatchewan(
    LateFamilyDayMixin, VictoriaDayMixin, RemembranceDayShiftMixin, AugustCivicHolidayMixin, ThanksgivingMixin, Canada
):
    include_good_friday: ClassVar[bool]
    def get_variable_days(self, year): ...

class Manitoba(LateFamilyDayMixin, VictoriaDayMixin, AugustCivicHolidayMixin, ThanksgivingMixin, Canada):
    include_good_friday: ClassVar[bool]
    def get_variable_days(self, year): ...

class NewBrunswick(AugustCivicHolidayMixin, Canada):
    FIXED_HOLIDAYS: Incomplete
    include_good_friday: ClassVar[bool]
    def get_variable_days(self, year): ...

class NovaScotia(RemembranceDayShiftMixin, LateFamilyDayMixin, Canada):
    include_good_friday: ClassVar[bool]
    def get_variable_days(self, year): ...

class PrinceEdwardIsland(LateFamilyDayMixin, RemembranceDayShiftMixin, Canada):
    include_good_friday: ClassVar[bool]
    def get_variable_days(self, year): ...

class Newfoundland(Canada):
    include_good_friday: ClassVar[bool]

class Yukon(VictoriaDayMixin, ThanksgivingMixin, Canada):
    FIXED_HOLIDAYS: Incomplete
    include_good_friday: ClassVar[bool]
    def get_variable_days(self, year): ...

class NorthwestTerritories(RemembranceDayShiftMixin, VictoriaDayMixin, ThanksgivingMixin, Canada):
    FIXED_HOLIDAYS: Incomplete
    include_good_friday: ClassVar[bool]
    def get_variable_days(self, year): ...

class Nunavut(VictoriaDayMixin, ThanksgivingMixin, RemembranceDayShiftMixin, Canada):
    include_good_friday: ClassVar[bool]
    def get_variable_days(self, year): ...



from _typeshed import SupportsItems
from typing import TypeVar

_KT = TypeVar("_KT")
_VT = TypeVar("_VT")

BOOL_CONFIG: set[str]

def asbool(obj: object) -> bool: ...
def convert_config(config: SupportsItems[_KT, _VT]) -> dict[_KT, _VT | bool]: ...



from _typeshed import Incomplete

class RoutesQuery:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        _self: Incomplete | None = None,
        ast: Incomplete | None = None,
        analyze: Incomplete | None = None,
        suggestions: Incomplete | None = None,
    ) -> None: ...
    @property
    def ast(self): ...
    @ast.setter
    def ast(self, ast) -> None: ...
    @property
    def analyze(self): ...
    @analyze.setter
    def analyze(self, analyze) -> None: ...
    @property
    def suggestions(self): ...
    @suggestions.setter
    def suggestions(self, suggestions) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

from influxdb_client import Configuration

LOGGERS_NAMES: Incomplete

class _BaseClient:
    url: str
    token: str | None
    org: str | None
    default_tags: Incomplete | None
    conf: _Configuration
    auth_header_name: Incomplete | None
    auth_header_value: Incomplete | None
    retries: bool | Incomplete
    profilers: Incomplete | None
    def __init__(
        self,
        url: str,
        token: str | None,
        debug: bool | None = None,
        timeout: int = 10000,
        enable_gzip: bool = False,
        org: str | None = None,
        default_tags: dict[Incomplete, Incomplete] | None = None,
        http_client_logger: str | None = None,
        *,
        verify_ssl: bool = ...,
        ssl_ca_cert: Incomplete | None = ...,
        cert_file: Incomplete | None = ...,
        cert_key_file: Incomplete | None = ...,
        cert_key_password: Incomplete | None = ...,
        ssl_context: Incomplete | None = ...,
        proxy: Incomplete | None = ...,
        proxy_headers: Incomplete | None = ...,
        connection_pool_maxsize: int = ...,
        username: Incomplete | None = ...,
        password: Incomplete | None = ...,
        auth_basic: bool = ...,
        retries: bool | Incomplete = ...,
        profilers: Incomplete | None = ...,
    ) -> None: ...

class _BaseQueryApi:
    default_dialect: Incomplete
    def __init__(self, influxdb_client, query_options: Incomplete | None = None) -> None: ...

class _BaseWriteApi:
    def __init__(self, influxdb_client, point_settings: Incomplete | None = None) -> None: ...

class _BaseDeleteApi:
    def __init__(self, influxdb_client) -> None: ...

class _Configuration(Configuration):
    enable_gzip: bool
    username: Incomplete
    password: Incomplete
    def __init__(self) -> None: ...
    def update_request_header_params(self, path: str, params: dict[Incomplete, Incomplete]): ...
    def update_request_body(self, path: str, body): ...



from influxdb_client.service.authorizations_service import AuthorizationsService as AuthorizationsService
from influxdb_client.service.backup_service import BackupService as BackupService
from influxdb_client.service.bucket_schemas_service import BucketSchemasService as BucketSchemasService
from influxdb_client.service.buckets_service import BucketsService as BucketsService
from influxdb_client.service.cells_service import CellsService as CellsService
from influxdb_client.service.checks_service import ChecksService as ChecksService
from influxdb_client.service.config_service import ConfigService as ConfigService
from influxdb_client.service.dashboards_service import DashboardsService as DashboardsService
from influxdb_client.service.dbr_ps_service import DBRPsService as DBRPsService
from influxdb_client.service.delete_service import DeleteService as DeleteService
from influxdb_client.service.health_service import HealthService as HealthService
from influxdb_client.service.invokable_scripts_service import InvokableScriptsService as InvokableScriptsService
from influxdb_client.service.labels_service import LabelsService as LabelsService
from influxdb_client.service.legacy_authorizations_service import LegacyAuthorizationsService as LegacyAuthorizationsService
from influxdb_client.service.metrics_service import MetricsService as MetricsService
from influxdb_client.service.notification_endpoints_service import NotificationEndpointsService as NotificationEndpointsService
from influxdb_client.service.notification_rules_service import NotificationRulesService as NotificationRulesService
from influxdb_client.service.organizations_service import OrganizationsService as OrganizationsService
from influxdb_client.service.ping_service import PingService as PingService
from influxdb_client.service.query_service import QueryService as QueryService
from influxdb_client.service.ready_service import ReadyService as ReadyService
from influxdb_client.service.remote_connections_service import RemoteConnectionsService as RemoteConnectionsService
from influxdb_client.service.replications_service import ReplicationsService as ReplicationsService
from influxdb_client.service.resources_service import ResourcesService as ResourcesService
from influxdb_client.service.restore_service import RestoreService as RestoreService
from influxdb_client.service.routes_service import RoutesService as RoutesService
from influxdb_client.service.rules_service import RulesService as RulesService
from influxdb_client.service.scraper_targets_service import ScraperTargetsService as ScraperTargetsService
from influxdb_client.service.secrets_service import SecretsService as SecretsService
from influxdb_client.service.setup_service import SetupService as SetupService
from influxdb_client.service.signin_service import SigninService as SigninService
from influxdb_client.service.signout_service import SignoutService as SignoutService
from influxdb_client.service.sources_service import SourcesService as SourcesService
from influxdb_client.service.tasks_service import TasksService as TasksService
from influxdb_client.service.telegraf_plugins_service import TelegrafPluginsService as TelegrafPluginsService
from influxdb_client.service.telegrafs_service import TelegrafsService as TelegrafsService
from influxdb_client.service.templates_service import TemplatesService as TemplatesService
from influxdb_client.service.users_service import UsersService as UsersService
from influxdb_client.service.variables_service import VariablesService as VariablesService
from influxdb_client.service.views_service import ViewsService as ViewsService
from influxdb_client.service.write_service import WriteService as WriteService



from collections.abc import Generator, Mapping, MutableMapping
from io import StringIO
from typing import ClassVar, Literal
from typing_extensions import TypeAlias

def b2u(string: bytes | str) -> str: ...
def u2b(string: str | bytes) -> bytes: ...

_Quotes: TypeAlias = Literal["'", '"']
_ContextType: TypeAlias = Literal["ARG", "ENV", "LABEL"]

class WordSplitter:
    SQUOTE: ClassVar[_Quotes]
    DQUOTE: ClassVar[_Quotes]
    stream: StringIO
    args: Mapping[str, str] | None
    envs: Mapping[str, str] | None
    quotes: _Quotes | None
    escaped: bool
    def __init__(self, s: str, args: Mapping[str, str] | None = None, envs: Mapping[str, str] | None = None) -> None: ...
    def dequote(self) -> str: ...
    def split(self, maxsplit: int | None = None, dequote: bool = True) -> Generator[str | None, None, None]: ...

def extract_key_values(
    env_replace: bool, args: Mapping[str, str], envs: Mapping[str, str], instruction_value: str
) -> list[tuple[str, str]]: ...
def get_key_val_dictionary(
    instruction_value: str,
    env_replace: bool = False,
    args: Mapping[str, str] | None = None,
    envs: Mapping[str, str] | None = None,
) -> dict[str, str]: ...

class Context:
    args: MutableMapping[str, str]
    envs: MutableMapping[str, str]
    labels: MutableMapping[str, str]
    line_args: Mapping[str, str]
    line_envs: Mapping[str, str]
    line_labels: Mapping[str, str]
    def __init__(
        self,
        args: MutableMapping[str, str] | None = None,
        envs: MutableMapping[str, str] | None = None,
        labels: MutableMapping[str, str] | None = None,
        line_args: Mapping[str, str] | None = None,
        line_envs: Mapping[str, str] | None = None,
        line_labels: Mapping[str, str] | None = None,
    ) -> None: ...
    def set_line_value(self, context_type: _ContextType, value: Mapping[str, str]) -> None: ...
    def get_line_value(self, context_type: _ContextType) -> Mapping[str, str]: ...
    def get_values(self, context_type: _ContextType) -> Mapping[str, str]: ...



from collections.abc import Generator
from datetime import date, datetime, timedelta, tzinfo

def total_seconds(td: timedelta) -> float: ...
def dt_to_timestamp(dt: datetime) -> int: ...
def isoparse(iso_str: str) -> datetime: ...
def parse_timedelta(text: str) -> timedelta: ...

parse_td = parse_timedelta

def decimal_relative_time(
    d: datetime, other: datetime | None = None, ndigits: int = 0, cardinalize: bool = True
) -> tuple[float, str]: ...
def relative_time(d: datetime, other: datetime | None = None, ndigits: int = 0) -> str: ...
def strpdate(string: str, format: str) -> date: ...
def daterange(start: date, stop: date, step: int = 1, inclusive: bool = False) -> Generator[date, None, None]: ...

ZERO: timedelta
HOUR: timedelta

class ConstantTZInfo(tzinfo):
    name: str
    offset: timedelta
    def __init__(self, name: str = "ConstantTZ", offset: timedelta = ...) -> None: ...
    @property
    def utcoffset_hours(self) -> str: ...
    def utcoffset(self, dt: datetime | None) -> timedelta: ...
    def tzname(self, dt: datetime | None) -> str: ...
    def dst(self, dt: datetime | None) -> timedelta: ...

UTC: ConstantTZInfo
EPOCH_AWARE: datetime
EPOCH_NAIVE: datetime

class LocalTZInfo(tzinfo):
    def is_dst(self, dt: datetime) -> bool: ...
    def utcoffset(self, dt: datetime | None) -> timedelta: ...
    def dst(self, dt: datetime | None) -> timedelta: ...
    def tzname(self, dt: datetime | None) -> str: ...

LocalTZ: LocalTZInfo
DSTSTART_2007: datetime
DSTEND_2007: datetime
DSTSTART_1987_2006: datetime
DSTEND_1987_2006: datetime
DSTSTART_1967_1986: datetime
DSTEND_1967_1986: datetime

class USTimeZone(tzinfo):
    stdoffset: timedelta
    reprname: str
    stdname: str
    dstname: str
    def __init__(self, hours: int, reprname: str, stdname: str, dstname: str) -> None: ...
    def tzname(self, dt: datetime | None) -> str: ...
    def utcoffset(self, dt: datetime | None) -> timedelta: ...
    def dst(self, dt: datetime | None) -> timedelta: ...

Eastern: USTimeZone
Central: USTimeZone
Mountain: USTimeZone
Pacific: USTimeZone



from _typeshed import Incomplete

class TemplateSummaryDiff:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        buckets: Incomplete | None = None,
        checks: Incomplete | None = None,
        dashboards: Incomplete | None = None,
        labels: Incomplete | None = None,
        label_mappings: Incomplete | None = None,
        notification_endpoints: Incomplete | None = None,
        notification_rules: Incomplete | None = None,
        tasks: Incomplete | None = None,
        telegraf_configs: Incomplete | None = None,
        variables: Incomplete | None = None,
    ) -> None: ...
    @property
    def buckets(self): ...
    @buckets.setter
    def buckets(self, buckets) -> None: ...
    @property
    def checks(self): ...
    @checks.setter
    def checks(self, checks) -> None: ...
    @property
    def dashboards(self): ...
    @dashboards.setter
    def dashboards(self, dashboards) -> None: ...
    @property
    def labels(self): ...
    @labels.setter
    def labels(self, labels) -> None: ...
    @property
    def label_mappings(self): ...
    @label_mappings.setter
    def label_mappings(self, label_mappings) -> None: ...
    @property
    def notification_endpoints(self): ...
    @notification_endpoints.setter
    def notification_endpoints(self, notification_endpoints) -> None: ...
    @property
    def notification_rules(self): ...
    @notification_rules.setter
    def notification_rules(self, notification_rules) -> None: ...
    @property
    def tasks(self): ...
    @tasks.setter
    def tasks(self, tasks) -> None: ...
    @property
    def telegraf_configs(self): ...
    @telegraf_configs.setter
    def telegraf_configs(self, telegraf_configs) -> None: ...
    @property
    def variables(self): ...
    @variables.setter
    def variables(self, variables) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import StrPath
from collections.abc import Iterator

xdg_data_home: str
xdg_data_dirs: list[str]
xdg_config_home: str
xdg_config_dirs: list[str]
xdg_cache_home: str
xdg_state_home: str

def save_config_path(*resource: StrPath) -> str: ...
def save_data_path(*resource: StrPath) -> str: ...
def save_cache_path(*resource: StrPath) -> str: ...
def save_state_path(*resource: StrPath) -> str: ...
def load_config_paths(*resource: StrPath) -> Iterator[str]: ...
def load_first_config(*resource: StrPath) -> str: ...
def load_data_paths(*resource: StrPath) -> Iterator[str]: ...
def get_runtime_dir(strict: bool = True) -> str: ...



from collections.abc import Callable, Collection, Iterable
from decimal import Decimal
from re import Match, Pattern
from typing import Any, TypeVar, overload

from wtforms.fields import Field, StringField
from wtforms.form import BaseForm

_ValuesT = TypeVar("_ValuesT", bound=Collection[Any], contravariant=True)

class ValidationError(ValueError):
    def __init__(self, message: str = "", *args: object) -> None: ...

class StopValidation(Exception):
    def __init__(self, message: str = "", *args: object) -> None: ...

class EqualTo:
    fieldname: str
    message: str | None
    def __init__(self, fieldname: str, message: str | None = None) -> None: ...
    def __call__(self, form: BaseForm, field: Field) -> None: ...

class Length:
    min: int
    max: int
    message: str | None
    field_flags: dict[str, Any]
    def __init__(self, min: int = -1, max: int = -1, message: str | None = None) -> None: ...
    def __call__(self, form: BaseForm, field: StringField) -> None: ...

class NumberRange:
    min: float | Decimal | None
    max: float | Decimal | None
    message: str | None
    field_flags: dict[str, Any]
    def __init__(
        self, min: float | Decimal | None = None, max: float | Decimal | None = None, message: str | None = None
    ) -> None: ...
    # any numeric field will work, for now we don't try to use a union
    # to restrict to the defined numeric fields, since user-defined fields
    # will likely not use a common base class, just like the existing
    # numeric fields
    def __call__(self, form: BaseForm, field: Field) -> None: ...

class Optional:
    string_check: Callable[[str], bool]
    field_flags: dict[str, Any]
    def __init__(self, strip_whitespace: bool = True) -> None: ...
    def __call__(self, form: BaseForm, field: Field) -> None: ...

class DataRequired:
    message: str | None
    field_flags: dict[str, Any]
    def __init__(self, message: str | None = None) -> None: ...
    def __call__(self, form: BaseForm, field: Field) -> None: ...

class InputRequired:
    message: str | None
    field_flags: dict[str, Any]
    def __init__(self, message: str | None = None) -> None: ...
    def __call__(self, form: BaseForm, field: Field) -> None: ...

class Regexp:
    regex: Pattern[str]
    message: str | None
    def __init__(self, regex: str | Pattern[str], flags: int = 0, message: str | None = None) -> None: ...
    def __call__(self, form: BaseForm, field: StringField, message: str | None = None) -> Match[str]: ...

class Email:
    message: str | None
    granular_message: bool
    check_deliverability: bool
    allow_smtputf8: bool
    allow_empty_local: bool
    def __init__(
        self,
        message: str | None = None,
        granular_message: bool = False,
        check_deliverability: bool = False,
        allow_smtputf8: bool = True,
        allow_empty_local: bool = False,
    ) -> None: ...
    def __call__(self, form: BaseForm, field: StringField) -> None: ...

class IPAddress:
    ipv4: bool
    ipv6: bool
    message: str | None
    def __init__(self, ipv4: bool = True, ipv6: bool = False, message: str | None = None) -> None: ...
    def __call__(self, form: BaseForm, field: StringField) -> None: ...
    @classmethod
    def check_ipv4(cls, value: str | None) -> bool: ...
    @classmethod
    def check_ipv6(cls, value: str | None) -> bool: ...

class MacAddress(Regexp):
    def __init__(self, message: str | None = None) -> None: ...
    def __call__(self, form: BaseForm, field: StringField) -> None: ...  # type: ignore[override]

class URL(Regexp):
    validate_hostname: HostnameValidation
    def __init__(self, require_tld: bool = True, allow_ip: bool = True, message: str | None = None) -> None: ...
    def __call__(self, form: BaseForm, field: StringField) -> None: ...  # type: ignore[override]

class UUID:
    message: str | None
    def __init__(self, message: str | None = None) -> None: ...
    def __call__(self, form: BaseForm, field: StringField) -> None: ...

class AnyOf:
    values: Collection[Any]
    message: str | None
    values_formatter: Callable[[Any], str]
    @overload
    def __init__(self, values: Collection[Any], message: str | None = None, values_formatter: None = None) -> None: ...
    @overload
    def __init__(self, values: _ValuesT, message: str | None, values_formatter: Callable[[_ValuesT], str]) -> None: ...
    @overload
    def __init__(self, values: _ValuesT, message: str | None = None, *, values_formatter: Callable[[_ValuesT], str]) -> None: ...
    def __call__(self, form: BaseForm, field: Field) -> None: ...
    @staticmethod
    def default_values_formatter(values: Iterable[object]) -> str: ...

class NoneOf:
    values: Collection[Any]
    message: str | None
    values_formatter: Callable[[Any], str]
    @overload
    def __init__(self, values: Collection[Any], message: str | None = None, values_formatter: None = None) -> None: ...
    @overload
    def __init__(self, values: _ValuesT, message: str | None, values_formatter: Callable[[_ValuesT], str]) -> None: ...
    @overload
    def __init__(self, values: _ValuesT, message: str | None = None, *, values_formatter: Callable[[_ValuesT], str]) -> None: ...
    def __call__(self, form: BaseForm, field: Field) -> None: ...
    @staticmethod
    def default_values_formatter(v: Iterable[object]) -> str: ...

class HostnameValidation:
    hostname_part: Pattern[str]
    tld_part: Pattern[str]
    require_tld: bool
    allow_ip: bool
    def __init__(self, require_tld: bool = True, allow_ip: bool = False) -> None: ...
    def __call__(self, hostname: str) -> bool: ...

class ReadOnly:
    def __call__(self, form: BaseForm, field: Field) -> None: ...

class Disabled:
    def __call__(self, form: BaseForm, field: Field) -> None: ...

email = Email
equal_to = EqualTo
ip_address = IPAddress
mac_address = MacAddress
length = Length
number_range = NumberRange
optional = Optional
input_required = InputRequired
data_required = DataRequired
regexp = Regexp
url = URL
any_of = AnyOf
none_of = NoneOf
readonly = ReadOnly
disabled = Disabled



import sys
from collections.abc import Mapping
from distutils.ccompiler import CCompiler
from typing import Literal, overload
from typing_extensions import deprecated

PREFIX: str
EXEC_PREFIX: str
BASE_PREFIX: str
BASE_EXEC_PREFIX: str
project_base: str
python_build: bool

def expand_makefile_vars(s: str, vars: Mapping[str, str]) -> str: ...
@overload
@deprecated("SO is deprecated, use EXT_SUFFIX. Support is removed in Python 3.11")
def get_config_var(name: Literal["SO"]) -> int | str | None: ...
@overload
def get_config_var(name: str) -> int | str | None: ...
@overload
def get_config_vars() -> dict[str, str | int]: ...
@overload
def get_config_vars(arg: str, /, *args: str) -> list[str | int]: ...
def get_config_h_filename() -> str: ...
def get_makefile_filename() -> str: ...
def get_python_inc(plat_specific: bool = ..., prefix: str | None = None) -> str: ...
def get_python_lib(plat_specific: bool = ..., standard_lib: bool = ..., prefix: str | None = None) -> str: ...
def customize_compiler(compiler: CCompiler) -> None: ...

if sys.version_info < (3, 10):
    def get_python_version() -> str: ...



from collections.abc import Callable
from contextvars import Context
from types import FrameType, TracebackType
from typing import Any, Literal, Protocol, overload
from typing_extensions import TypeAlias

_TraceEvent: TypeAlias = Literal["switch", "throw"]
_TraceCallback: TypeAlias = Callable[[_TraceEvent, tuple[greenlet, greenlet]], object]

CLOCKS_PER_SEC: int
GREENLET_USE_CONTEXT_VARS: bool
GREENLET_USE_GC: bool
GREENLET_USE_STANDARD_THREADING: bool
GREENLET_USE_TRACING: bool
# this is a PyCapsule, it may be used to pass the gevent C-API to another C-extension
# there isn't a runtime type for this, since it's only an opaque wrapper around void*
# but it's probably still better than pretending it doesn't exist, so people that need
# to pass this around, can still pass it around without having to ignore type errors...
_C_API: object

class _ParentDescriptor(Protocol):
    def __get__(self, obj: greenlet, owner: type[greenlet] | None = None) -> greenlet | None: ...
    def __set__(self, obj: greenlet, value: greenlet) -> None: ...

class GreenletExit(BaseException): ...
class error(Exception): ...

class greenlet:
    @property
    def dead(self) -> bool: ...
    @property
    def gr_context(self) -> Context | None: ...
    @gr_context.setter
    def gr_context(self, value: Context | None) -> None: ...
    @property
    def gr_frame(self) -> FrameType | None: ...
    # the parent attribute is a bit special, since it can't be set to `None` manually, but
    # it can be `None` for the master greenlet which will always be around, regardless of
    # how many greenlets have been spawned explicitly. Since there can only be one such
    # greenlet per thread, there is no way to create another one manually.
    parent: _ParentDescriptor
    @property
    def run(self) -> Callable[..., Any]: ...
    @run.setter
    def run(self, value: Callable[..., Any]) -> None: ...
    def __init__(self, run: Callable[..., Any] | None = None, parent: greenlet | None = None) -> None: ...
    def switch(self, *args: Any, **kwargs: Any) -> Any: ...
    @overload
    def throw(
        self, typ: type[BaseException] = ..., val: BaseException | object = None, tb: TracebackType | None = None, /
    ) -> Any: ...
    @overload
    def throw(self, typ: BaseException = ..., val: None = None, tb: TracebackType | None = None, /) -> Any: ...
    def __bool__(self) -> bool: ...

    # aliases for some module attributes/methods
    GreenletExit: type[GreenletExit]
    error: type[error]
    @staticmethod
    def getcurrent() -> greenlet: ...
    @staticmethod
    def gettrace() -> _TraceCallback | None: ...
    @staticmethod
    def settrace(callback: _TraceCallback | None, /) -> _TraceCallback | None: ...

class UnswitchableGreenlet(greenlet):  # undocumented
    force_switch_error: bool
    force_slp_switch_error: bool

def enable_optional_cleanup(enabled: bool, /) -> None: ...
def get_clocks_used_doing_optional_cleanup() -> int: ...
def get_pending_cleanup_count() -> int: ...
def get_total_main_greenlets() -> int: ...
def get_tstate_trash_delete_nesting() -> int: ...
def getcurrent() -> greenlet: ...
def gettrace() -> _TraceCallback | None: ...
def set_thread_local(key: object, value: object, /) -> None: ...
def settrace(callback: _TraceCallback | None, /) -> _TraceCallback | None: ...



from _typeshed import Incomplete, StrPath
from collections.abc import Callable, Iterable, Iterator, Mapping
from importlib.machinery import ModuleSpec
from types import TracebackType
from typing import TypeVar
from typing_extensions import Self

from ..dist import Distribution

chain_iter: Incomplete
_K = TypeVar("_K")
_VCo = TypeVar("_VCo", covariant=True)

class StaticModule:
    def __init__(self, name: str, spec: ModuleSpec) -> None: ...
    def __getattr__(self, attr): ...

def glob_relative(patterns: Iterable[str], root_dir: StrPath | None = None) -> list[str]: ...
def read_files(filepaths: str | bytes | Iterable[StrPath], root_dir: Incomplete | None = None) -> str: ...
def read_attr(attr_desc: str, package_dir: Mapping[str, str] | None = None, root_dir: StrPath | None = None): ...
def resolve_class(
    qualified_class_name: str, package_dir: Mapping[str, str] | None = None, root_dir: StrPath | None = None
) -> Callable[..., Incomplete]: ...
def cmdclass(
    values: dict[str, str], package_dir: Mapping[str, str] | None = None, root_dir: StrPath | None = None
) -> dict[str, Callable[..., Incomplete]]: ...
def find_packages(
    *, namespaces: bool = True, fill_package_dir: dict[str, str] | None = None, root_dir: StrPath | None = None, **kwargs
) -> list[str]: ...
def version(value: Callable[..., Incomplete] | Iterable[str | int] | str) -> str: ...
def canonic_package_data(package_data: dict[Incomplete, Incomplete]) -> dict[Incomplete, Incomplete]: ...
def canonic_data_files(
    data_files: list[Incomplete] | dict[Incomplete, Incomplete], root_dir: StrPath | None = None
) -> list[tuple[str, list[str]]]: ...
def entry_points(text: str, text_source: str = "entry-points") -> dict[str, dict[Incomplete, Incomplete]]: ...

class EnsurePackagesDiscovered:
    def __init__(self, distribution: Distribution) -> None: ...
    def __call__(self) -> None: ...
    def __enter__(self) -> Self: ...
    def __exit__(
        self, _exc_type: type[BaseException] | None, _exc_value: BaseException | None, _traceback: TracebackType | None
    ) -> None: ...
    @property
    def package_dir(self) -> Mapping[str, str]: ...

class LazyMappingProxy(Mapping[_K, _VCo]):
    def __init__(self, obtain_mapping_value: Callable[[], Mapping[_K, _VCo]]) -> None: ...
    def __getitem__(self, key: _K) -> _VCo: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[_K]: ...



from collections.abc import Callable
from types import TracebackType
from typing import TypeVar
from typing_extensions import ParamSpec, Self

_AC = TypeVar("_AC", bound=Callable[..., object])
_R = TypeVar("_R")
_P = ParamSpec("_P")

class Python:
    def __init__(self, strict_mode: bool | None = None) -> None: ...
    def __enter__(self) -> Self: ...
    def __exit__(
        self, exc_type: type[BaseException] | None, exc_val: BaseException | None, exc_tb: TracebackType | None
    ) -> None: ...
    def call(self, function: Callable[_P, _R], *args: _P.args, **kwargs: _P.kwargs) -> _R: ...

def call(function: Callable[_P, _R], *args: _P.args, **kwargs: _P.kwargs) -> _R: ...
def decorate(function: _AC) -> _AC: ...



from typing import Any
from typing_extensions import Self

log: Any
ROOT: str
PARENT: str
SAMPLE: str
SELF: str
HEADER_DELIMITER: str

class TraceHeader:
    def __init__(
        self, root: str | None = None, parent: str | None = None, sampled: bool | None = None, data: dict[str, Any] | None = None
    ) -> None: ...
    @classmethod
    def from_header_str(cls, header) -> Self: ...
    def to_header_str(self): ...
    @property
    def root(self): ...
    @property
    def parent(self): ...
    @property
    def sampled(self): ...
    @property
    def data(self): ...



from _typeshed import (
    BytesPath,
    Incomplete,
    OpenBinaryMode,
    OpenBinaryModeReading,
    OpenBinaryModeUpdating,
    OpenBinaryModeWriting,
    OpenTextMode,
    StrOrBytesPath,
    StrPath,
)
from asyncio import AbstractEventLoop
from typing import AnyStr, Literal, TypeVar, overload

from ..base import AiofilesContextManager
from ..threadpool.binary import AsyncBufferedIOBase, AsyncBufferedReader, AsyncFileIO
from ..threadpool.text import AsyncTextIOWrapper
from .temptypes import AsyncTemporaryDirectory

_T_co = TypeVar("_T_co", covariant=True)
_V_co = TypeVar("_V_co", covariant=True)
_T_contra = TypeVar("_T_contra", contravariant=True)

# Text mode: always returns AsyncTextIOWrapper
@overload
def NamedTemporaryFile(
    mode: OpenTextMode,
    buffering: int = -1,
    encoding: str | None = None,
    newline: str | None = None,
    suffix: AnyStr | None = None,
    prefix: AnyStr | None = None,
    dir: StrOrBytesPath | None = None,
    delete: bool = True,
    loop: AbstractEventLoop | None = None,
    executor: Incomplete | None = None,
) -> AiofilesContextManager[None, None, AsyncTextIOWrapper]: ...

# Unbuffered binary: returns a FileIO
@overload
def NamedTemporaryFile(
    mode: OpenBinaryMode,
    buffering: Literal[0],
    encoding: None = None,
    newline: None = None,
    suffix: AnyStr | None = None,
    prefix: AnyStr | None = None,
    dir: StrOrBytesPath | None = None,
    delete: bool = True,
    loop: AbstractEventLoop | None = None,
    executor: Incomplete | None = None,
) -> AiofilesContextManager[None, None, AsyncFileIO]: ...

# Buffered binary reading/updating: AsyncBufferedReader
@overload
def NamedTemporaryFile(
    mode: OpenBinaryModeReading | OpenBinaryModeUpdating = "w+b",
    buffering: Literal[-1, 1] = -1,
    encoding: None = None,
    newline: None = None,
    suffix: AnyStr | None = None,
    prefix: AnyStr | None = None,
    dir: StrOrBytesPath | None = None,
    delete: bool = True,
    loop: AbstractEventLoop | None = None,
    executor: Incomplete | None = None,
) -> AiofilesContextManager[None, None, AsyncBufferedReader]: ...

# Buffered binary writing: AsyncBufferedIOBase
@overload
def NamedTemporaryFile(
    mode: OpenBinaryModeWriting,
    buffering: Literal[-1, 1] = -1,
    encoding: None = None,
    newline: None = None,
    suffix: AnyStr | None = None,
    prefix: AnyStr | None = None,
    dir: StrOrBytesPath | None = None,
    delete: bool = True,
    loop: AbstractEventLoop | None = None,
    executor: Incomplete | None = None,
) -> AiofilesContextManager[None, None, AsyncBufferedIOBase]: ...

# Text mode: always returns AsyncTextIOWrapper
@overload
def TemporaryFile(
    mode: OpenTextMode,
    buffering: int = -1,
    encoding: str | None = None,
    newline: str | None = None,
    suffix: AnyStr | None = None,
    prefix: AnyStr | None = None,
    dir: StrOrBytesPath | None = None,
    loop: AbstractEventLoop | None = None,
    executor: Incomplete | None = None,
) -> AiofilesContextManager[None, None, AsyncTextIOWrapper]: ...

# Unbuffered binary: returns a FileIO
@overload
def TemporaryFile(
    mode: OpenBinaryMode,
    buffering: Literal[0],
    encoding: None = None,
    newline: None = None,
    suffix: AnyStr | None = None,
    prefix: AnyStr | None = None,
    dir: StrOrBytesPath | None = None,
    loop: AbstractEventLoop | None = None,
    executor: Incomplete | None = None,
) -> AiofilesContextManager[None, None, AsyncFileIO]: ...

# Buffered binary reading/updating: AsyncBufferedReader
@overload
def TemporaryFile(
    mode: OpenBinaryModeReading | OpenBinaryModeUpdating = "w+b",
    buffering: Literal[-1, 1] = -1,
    encoding: None = None,
    newline: None = None,
    suffix: AnyStr | None = None,
    prefix: AnyStr | None = None,
    dir: StrOrBytesPath | None = None,
    loop: AbstractEventLoop | None = None,
    executor: Incomplete | None = None,
) -> AiofilesContextManager[None, None, AsyncBufferedReader]: ...

# Buffered binary writing: AsyncBufferedIOBase
@overload
def TemporaryFile(
    mode: OpenBinaryModeWriting,
    buffering: Literal[-1, 1] = -1,
    encoding: None = None,
    newline: None = None,
    suffix: AnyStr | None = None,
    prefix: AnyStr | None = None,
    dir: StrOrBytesPath | None = None,
    loop: AbstractEventLoop | None = None,
    executor: Incomplete | None = None,
) -> AiofilesContextManager[None, None, AsyncBufferedIOBase]: ...

# Text mode: always returns AsyncTextIOWrapper
@overload
def SpooledTemporaryFile(
    max_size: int = 0,
    *,
    mode: OpenTextMode,
    buffering: int = -1,
    encoding: str | None = None,
    newline: str | None = None,
    suffix: AnyStr | None = None,
    prefix: AnyStr | None = None,
    dir: StrOrBytesPath | None = None,
    loop: AbstractEventLoop | None = None,
    executor: Incomplete | None = None,
) -> AiofilesContextManager[None, None, AsyncTextIOWrapper]: ...
@overload
def SpooledTemporaryFile(
    max_size: int,
    mode: OpenTextMode,
    buffering: int = -1,
    encoding: str | None = None,
    newline: str | None = None,
    suffix: AnyStr | None = None,
    prefix: AnyStr | None = None,
    dir: StrOrBytesPath | None = None,
    loop: AbstractEventLoop | None = None,
    executor: Incomplete | None = None,
) -> AiofilesContextManager[None, None, AsyncTextIOWrapper]: ...

# Unbuffered binary: returns a FileIO
@overload
def SpooledTemporaryFile(
    max_size: int = 0,
    mode: OpenBinaryMode = "w+b",
    *,
    buffering: Literal[0],
    encoding: None = None,
    newline: None = None,
    suffix: AnyStr | None = None,
    prefix: AnyStr | None = None,
    dir: StrOrBytesPath | None = None,
    loop: AbstractEventLoop | None = None,
    executor: Incomplete | None = None,
) -> AiofilesContextManager[None, None, AsyncFileIO]: ...
@overload
def SpooledTemporaryFile(
    max_size: int,
    mode: OpenBinaryMode,
    buffering: Literal[0],
    encoding: None = None,
    newline: None = None,
    suffix: AnyStr | None = None,
    prefix: AnyStr | None = None,
    dir: StrOrBytesPath | None = None,
    loop: AbstractEventLoop | None = None,
    executor: Incomplete | None = None,
) -> AiofilesContextManager[None, None, AsyncFileIO]: ...

# Buffered binary reading/updating: AsyncBufferedReader
@overload
def SpooledTemporaryFile(
    max_size: int = 0,
    mode: OpenBinaryModeReading | OpenBinaryModeUpdating = "w+b",
    buffering: Literal[-1, 1] = -1,
    encoding: None = None,
    newline: None = None,
    suffix: AnyStr | None = None,
    prefix: AnyStr | None = None,
    dir: StrOrBytesPath | None = None,
    loop: AbstractEventLoop | None = None,
    executor: Incomplete | None = None,
) -> AiofilesContextManager[None, None, AsyncBufferedReader]: ...

# Buffered binary writing: AsyncBufferedIOBase
@overload
def SpooledTemporaryFile(
    max_size: int = 0,
    *,
    mode: OpenBinaryModeWriting,
    buffering: Literal[-1, 1] = -1,
    encoding: None = None,
    newline: None = None,
    suffix: AnyStr | None = None,
    prefix: AnyStr | None = None,
    dir: StrOrBytesPath | None = None,
    loop: AbstractEventLoop | None = None,
    executor: Incomplete | None = None,
) -> AiofilesContextManager[None, None, AsyncBufferedIOBase]: ...
@overload
def SpooledTemporaryFile(
    max_size: int,
    mode: OpenBinaryModeWriting,
    buffering: Literal[-1, 1] = -1,
    encoding: None = None,
    newline: None = None,
    suffix: AnyStr | None = None,
    prefix: AnyStr | None = None,
    dir: StrOrBytesPath | None = None,
    loop: AbstractEventLoop | None = None,
    executor: Incomplete | None = None,
) -> AiofilesContextManager[None, None, AsyncBufferedIOBase]: ...
@overload
def TemporaryDirectory(
    suffix: str | None = None,
    prefix: str | None = None,
    dir: StrPath | None = None,
    loop: AbstractEventLoop | None = None,
    executor: Incomplete | None = None,
) -> AiofilesContextManagerTempDir[None, None, AsyncTemporaryDirectory]: ...
@overload
def TemporaryDirectory(
    suffix: bytes | None = None,
    prefix: bytes | None = None,
    dir: BytesPath | None = None,
    loop: AbstractEventLoop | None = None,
    executor: Incomplete | None = None,
) -> AiofilesContextManagerTempDir[None, None, AsyncTemporaryDirectory]: ...

class AiofilesContextManagerTempDir(AiofilesContextManager[_T_co, _T_contra, _V_co]):
    async def __aenter__(self) -> str: ...  # type: ignore[override]



from networkx.utils.backends import _dispatch

@_dispatch
def subgraph_centrality_exp(G): ...
@_dispatch
def subgraph_centrality(G): ...
@_dispatch
def communicability_betweenness_centrality(G): ...
@_dispatch
def estrada_index(G): ...



class ReasonCodes:
    packetType: int
    names: dict[int, dict[str, list[int]]]
    value: int
    def __init__(self, packetType: int, aName: str = "Success", identifier: int = -1) -> None: ...
    def __getName__(self, packetType: int, identifier: int) -> str: ...
    def getId(self, name: str) -> int: ...
    def set(self, name: str) -> None: ...
    def unpack(self, buffer: bytearray) -> int: ...
    def getName(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def json(self) -> str: ...
    def pack(self) -> bytearray: ...



from _typeshed import Incomplete

from influxdb_client.domain.statement import Statement

class MemberAssignment(Statement):
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self, type: Incomplete | None = None, member: Incomplete | None = None, init: Incomplete | None = None
    ) -> None: ...
    @property
    def type(self): ...
    @type.setter
    def type(self, type) -> None: ...
    @property
    def member(self): ...
    @member.setter
    def member(self, member) -> None: ...
    @property
    def init(self): ...
    @init.setter
    def init(self, init) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
